#
# spec file for package alsa
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           alsa
BuildRequires:  doxygen pkg-config
%define package_version	1.0.24.1
License:        LGPLv2.1+
Group:          System/Libraries
Requires:       alsa-utils
Recommends:     alsa-plugins alsa-oss
PreReq:         %insserv_prereq %fillup_prereq
AutoReqProv:    on
# bug437293
%ifarch ppc64
Obsoletes:      alsa-64bit
%endif
#
Summary:        Advanced Linux Sound Architecture
Version:        1.0.24.1
Release:        4.9.1
Source:         ftp://ftp.alsa-project.org/pub/lib/alsa-lib-%{package_version}.tar.bz2
Source2:        baselibs.conf
Source8:        40-alsa.rules
Source11:       alsasound
Source12:       sysconfig.sound
Source13:       joystick
Source14:       sysconfig.joystick
Source16:       set_default_volume
Source17:       test.wav
Source20:       README.SuSE
Source21:       README.testwav
Source30:       all_notes_off
Source31:       all_notes_off.bin
Source32:       all_notes_off.mid
Source33:       alsa-info.sh
Source34:       alsa-init.sh
# Patch:          alsa-lib-git-fixes.diff
Patch1:         alsa-lib-doxygen-avoid-crash-for-11.3.diff
Url:            http://www.alsa-project.org/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
ALSA stands for Advanced Linux Sound Architecture.  It supports many
PCI, ISA PnP  and USB sound cards.

This package contains the ALSA init scripts to start the sound system
on your Linux box.  To set it up, run yast2 or alsaconf.



Authors:
--------
    Jaroslav Kysela <perex@perex.cz>
    Takashi Iwai <tiwai@suse.de>

%package devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
License:        LGPLv2.1+
Requires:       glibc-devel, libasound2 = %{version}
Obsoletes:      alsadev
Provides:       alsadev alsa-lib-devel

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.



Authors:
--------
    Jaroslav Kysela <perex@perex.cz>
    Takashi Iwai <tiwai@suse.de>

%package docs
Summary:        Additional Package Documentation
Group:          Documentation/Other
License:        GPLv2+
%if %suse_version > 1110
BuildArch:      noarch
%endif

%description docs
This package contains optional documentation provided in addition to
this package's base documentation.



Authors:
--------
    Jaroslav Kysela <perex@perex.cz>
    Takashi Iwai <tiwai@suse.de>

%package -n libasound2
Summary:        Advanced Linux Sound Architecture Library
Group:          System/Libraries
Provides:       alsa-lib
License:        LGPLv2.1+

%description -n libasound2
This package contains the library for ALSA, Advanced Linux Sound
Architecture.



Authors:
--------
    Jaroslav Kysela <perex@perex.cz>
    Takashi Iwai <tiwai@suse.de>

%prep
%setup -q -n alsa-lib-%{package_version}
# %patch -p1
%if %suse_version == 1130
%patch1 -p1
%endif
# hack to fix build on older distros
%if %suse_version < 1100
%ifarch %ix86
test -f $RPM_SOURCE_DIR/baselibs.conf && \
sed -i -e'/recommends.*alsa-oss/d' $RPM_SOURCE_DIR/baselibs.conf
%endif
%endif

%build
export AUTOMAKE_JOBS=%{?jobs:%jobs}
# build alsa-lib
autoreconf -fi
%configure \
  --disable-static \
  --enable-symbolic-functions \
  --disable-aload \
  --disable-alisp \
  --disable-python
make V=1 %{?jobs:-j %jobs}
# run doxygen
make -C doc doc

%install
# install shared library
%makeinstall
# clean up unneeded files
rm -f $RPM_BUILD_ROOT%{_libdir}/*.*a
rm -f $RPM_BUILD_ROOT%{_libdir}/alsa-lib/smixer/*.*a
rm -f $RPM_BUILD_ROOT%{_bindir}/aserver
#
# install helper scripts
mkdir -p $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT%{_sbindir}
install -c -m 0755 %{SOURCE16} $RPM_BUILD_ROOT%{_bindir}
install -c -m 0755 %{SOURCE34} $RPM_BUILD_ROOT%{_sbindir}/alsa-init
%if %suse_version < 1140
sed -i -e 's@/var/lib/alsa/asound.state@/etc/asound.state@g' $RPM_BUILD_ROOT%{_bindir}/set_default_volume
sed -i -e 's@/var/lib/alsa/asound.state@/etc/asound.state@g' $RPM_BUILD_ROOT%{_sbindir}/alsa-init
%endif
# install test wave file
mkdir -p $RPM_BUILD_ROOT%{_datadir}/sounds/alsa
install -c -m 0644 %{SOURCE17} $RPM_BUILD_ROOT%{_datadir}/sounds/alsa/test.wav
# install all_notes_off stuff
install -c -m 0755 %{SOURCE30} $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT/usr/lib
install -c -m 0644 %{SOURCE31} $RPM_BUILD_ROOT/usr/lib
install -c -m 0644 %{SOURCE32} $RPM_BUILD_ROOT/usr/lib
#
# install init scripts
#
mkdir -p $RPM_BUILD_ROOT/etc/init.d
install -c -m 0755 %{SOURCE11} $RPM_BUILD_ROOT/etc/init.d
install -c -m 0755 %{SOURCE13} $RPM_BUILD_ROOT/etc/init.d
%if %suse_version < 1140
sed -i -e 's@/var/lib/alsa/asound.state@/etc/asound.state@g' $RPM_BUILD_ROOT/etc/init.d/alsasound
%endif
rm -f $RPM_BUILD_ROOT%{_sbindir}/rcalsasound
ln -s ../../etc/init.d/alsasound $RPM_BUILD_ROOT%{_sbindir}/rcalsasound
rm -f $RPM_BUILD_ROOT%{_sbindir}/rcjoystick
ln -s ../../etc/init.d/joystick $RPM_BUILD_ROOT%{_sbindir}/rcjoystick
#
# udev rules (only for non-systemd)
#
%if %suse_version < 1140
mkdir -p $RPM_BUILD_ROOT/etc/udev/rules.d
install -c -m 0644 %{SOURCE8} $RPM_BUILD_ROOT/etc/udev/rules.d
%endif
#
# install template to update rc.config and sysconfig files:
# (updating the actual files is done in the %post-script)
#
mkdir -p -m 755 $RPM_BUILD_ROOT/var/adm/fillup-templates
mkdir -p -m 755 $RPM_BUILD_ROOT/etc/sysconfig
for i in sound joystick; do
  install -m 644 $RPM_SOURCE_DIR/sysconfig.$i $RPM_BUILD_ROOT/var/adm/fillup-templates
done
#
# documents
#
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}
cp $RPM_SOURCE_DIR/README* $RPM_BUILD_ROOT%{_docdir}/%{name}
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}/alsa-lib
cp COPYING ChangeLog INSTALL TODO MEMORY-LEAK $RPM_BUILD_ROOT%{_docdir}/%{name}/alsa-lib
cp doc/asoundrc.txt $RPM_BUILD_ROOT%{_docdir}/%{name}/alsa-lib
# install alsa-info.sh to sbindir
install -c -m 0755 %{SOURCE33} $RPM_BUILD_ROOT%{_sbindir}

%post
%{fillup_and_insserv -ny sound alsasound}
%{fillup_and_insserv -n joystick joystick}
exit 0

%preun
%stop_on_removal alsasound joystick
exit 0

%postun
%restart_on_update alsasound joystick
%insserv_cleanup
exit 0

%post -n libasound2 -p /sbin/ldconfig

%postun -n libasound2 -p /sbin/ldconfig

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%files
%defattr(-, root, root)
%doc %{_docdir}/%{name}
/etc/init.d/*
%{_sbindir}/*
%{_bindir}/*
/usr/lib/all_notes_off.*
%{_datadir}/sounds/alsa
/var/adm/fillup-templates/*
%if %suse_version < 1140
/etc/udev
%endif

%files devel
%defattr(-, root, root)
%{_libdir}/libasound.so
%{_includedir}/sys/*
%{_includedir}/alsa
%{_datadir}/aclocal/*.m4
%{_libdir}/pkgconfig/*.pc

%files docs
%defattr(-, root, root)
%doc doc/doxygen/html/*

%files -n libasound2
%defattr(-, root, root)
%{_libdir}/libasound.so.*
%{_libdir}/alsa-lib
%{_datadir}/alsa

%changelog
* Tue Jul 12 2011 tiwai@suse.de
- Fix alsasound init script for separated /var partition
  (bnc#700781)
* Thu Mar 31 2011 tiwai@suse.de
- Fix typos in the previous fix; the correct path is
  /var/lib/alsa/asound.state
* Fri Mar 25 2011 tiwai@suse.de
- Fix asound.state path in other scripts, too
- Replace the asound.state path for older distros
* Thu Mar 24 2011 werner@suse.de
- Make boot script load modules on boot (bnc#682222)
- Correct location of saved sound state in the boot script (bnc#682222)
* Mon Jan 31 2011 tiwai@suse.de
- updated to version 1.0.24.1:
  * including previous fix patches
  * add the UCM (Use Cas Manager) framework
- Add a hack to avoid crash of doxygen on 11.3 builds
* Fri Nov 26 2010 tiwai@suse.de
- don't install udev rule for 11.4, as it's provided in alsa-utils
  now
* Wed Nov 24 2010 tiwai@suse.de
- Backport pending fixes from upstream:
  0027-Version-check-libtool-correctly-when-doing-an-out-of.patch
  0028-configure.in-don-t-rely-on-test-a-not-all-shells-sup.patch
  0029-pcm-direct-plugins-change-timestamping-in-dsnoop.patch
  0030-USB-Audio.conf-fix-Audiophile-USB-card-name.patch
  0031-pcm-pass-hw_params-flags-to-slave.patch
  0032-support-for-period-wakeup-disabling.patch
  0033-pcm-fix-snd_pcm_avail_delay-function.patch
  0034-pcm_plugin-remove-unused-client_frames-and-slave_fra.patch
  0035-pcm-add-MMAP_EMUL-to-type-names.patch
  0036-pcm_plugin-fix-delay.patch
* Mon Oct 25 2010 tiwai@suse.de
- Fix loopback config
  * 0022-Fix-typo-for-surround-PCMs-in-src-conf-cards-Loopbac.patch
- Fix config syntax for hw device
  * 0023-namehint-Fix-hw-device-evaluation-missing-last-devic.patch
  * 0024-namehint-Another-fix-to-properly-evaluate-hw-devices.patch
  * 0025-config-file-processing-rewrite-the-locking-use-one-r.patch
- Fix dB-volume range with mute bit (bnc#648925)
  * 0026-tlv-fix-returned-dB-information-for-min-is-mute-cont.patch
* Thu Sep  2 2010 tiwai@suse.de
- Backport patches from GIT:
  * 0001-Check-for-thread-specific-locale-support.patch
  * 0002-Use-thread-safe-locale-functions-if-available.patch
  * 0003-seq-Fix-for-snd_seq_parse_address.patch
  * 0004-control-tlv-Check-dB-range-only-within-the-control-s.patch
  * 0005-alisp-Fix-a-string-format-ambiguity.patch
  * 0006-tlv-Check-out-of-range-dB-with-SND_CTL_TLVT_DB_RANGE.patch
  * 0007-tlv-Handle-holes-in-SND_CTL_TLVT_DB_RANGE-array.patch
  * 0008-tlv-Remove-tailing-tab-after-snd_ctl_get_dB_range-fu.patch
  * 0009-Memory-leak-in-namehint.c.patch
  * 0010-pcm-ladspa-fix-small-memory-leak-in-snd_pcm_ladspa_f.patch
  * 0011-pcm_plug-fix-comparison-always-true.patch
  * 0012-test-latency-fix-timediff-calculation.patch
  * 0013-HDA-Intel-present-all-4-HDMI-outputs-instead-of-just.patch
  * 0014-pcm-add-defaults.pcm.minperiodtime-parsing.patch
  * 0015-pcm-introduce-defaults.pcm.compat-to-change-the-para.patch
  * 0016-pcm-Fixed-typo-wrong-deleted-line-instroduced-in-the.patch
  * 0017-Add-missing-support-for-3-byte-formats-for-16bit-put.patch
  * 0018-namehint-Evaluate-more-possibilities-for-hw-devices.patch
  * 0019-HDA-Intel-do-not-lock-IEC958-Playback-switch.patch
  * 0020-general-recoded-snd_dlobj_-functions.patch
  * 0021-Add-Loopback.conf-to-define-standard-PCM-devices-for.patch
* Thu May  6 2010 tiwai@suse.de
- fix the return code of alsasound (bnc#600767)
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Mon Apr 19 2010 tiwai@suse.de
- updated to version 1.0.23:
  * including previous fixes
  * pcm_share plugin: fix pcm->monotonic setup in open() function
* Mon Mar  8 2010 tiwai@suse.de
- backport upstream fixes:
  * modem.conf Off-hook improve behavior
  * pcm: fix read_areas and write_areas
  * Fix snd_pcm_sw_params_set_period_event() implementation
  * pcm_dmix: add support for S24_LE format
  * pcm direct plugins: drain() call might be blocked when threads are used
  * pcm: show errno in error messages
* Tue Dec 22 2009 tiwai@suse.de
- backport fix patches from GIT
  * pcm: Close event timer in pcm_hw plugin
  * Fix the sound distortions for S24_3LE stream in pcm_softvol
    plugin
* Fri Dec 18 2009 tiwai@suse.de
- set AUTOMAKE_JOBS for parallel automake
* Fri Dec 18 2009 tiwai@suse.de
- updated to version 1.0.22:
  * including previous fixes
  * a few fixes for alsactl init
* Wed Dec 16 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Tue Nov  3 2009 tiwai@suse.de
- backport major fix patches from alsa-lib GIT tree
  * pcm_hw: Always use delay ioctl in snd_pcm_delay()
  * dmix - Fix snd_pcm_info()
  * hcontrol: fix compare_default function to handle also
    id.device and id.subdevice
  * Fix corruption after snd_device_name_hint()
* Mon Nov  2 2009 tiwai@suse.de
- remove references to obsolete modprobe.d/sound file in init
  script (bnc#549905)
* Wed Sep  9 2009 tiwai@suse.de
- Fixes from upstream to fix conf parser error and audacious
  problems:
  * mixer: Add Speaker and Beep names to the weight list
  * Revert "Fix driver conf parsing in snd_config_hook_load_for_all_cards()"
  * Change dmix.conf to accept user configuration from defaults.dmix.<driver_id>.xxx
  * PCM - Change the hw_params determination order
- Mark docs subpackage as noarch
* Mon Aug 31 2009 tiwai@suse.de
- updated to version 1.0.21:
  just a version bump including previous fixes
* Wed Aug 26 2009 tiwai@suse.de
- fix alsa-info.sh possible symlink attach (bnc#533396,
  CVE-2009-0035)
- add -q to killall in alsasound init script to be more quiet
* Fri Aug 21 2009 tiwai@suse.de
- pcm: workaround for avoiding automatic start in mmap mode
- pcm/ioplug: fix error code in start callback
* Thu Aug 13 2009 tiwai@suse.de
- fix fuser usage in alsasound init script
- updated alsa-info.sh: check /sys/class/dmi first
* Mon Aug 10 2009 tiwai@suse.de
- Misc fixes backported from upstream:
  * Fix zero-division in pcm_rate.c
  * snd_pcm_scope_set_ops: make ops parameter const
  * timer_query: make ops structure constant
  * control.c: snd_ctl_wait: fix revents handling
  * Fix driver conf parsing in snd_config_hook_load_for_all_cards()
* Wed Aug  5 2009 tiwai@suse.de
- corrected various doc errors
- remove unimplemented functions from headers
- misc config parser fixes
- LSB test case for config stuff
* Mon Aug  3 2009 tiwai@suse.de
- Fix PA mute problem after reboot (bnc#499445)
* Mon Jul 20 2009 tiwai@suse.de
- minor improvement of alsa-info for dmesg output
- minor fixes in conf.c; renaming parameters, prevent adopting
  a non-orphan in snd_config_add()
* Thu Jul 16 2009 tiwai@suse.de
- Misc fixes in conf.c
- rawmidi: disable active-sensing-on-close by default
- USB-Audio.conf: fix definition for M-Audio AudioPhile spdif device
- LSB midi event test codes
- updated to alsa-info.sh to 0.4.57; don't upload the information
  as default; include relevant dmesg outputs
* Tue Jul  7 2009 tiwai@suse.de
- pcm_hooks: cosmetic removal of unused variables
- more midi_event documentation
- add midi event tests
- test/pcm.c: Sample generation on big endian platforms was broken.
- test/pcm.c: Fix S24 format
- test/pcm.c: Generic linear PCM support
- test/pcm.c: float format support
* Tue Jun 30 2009 tiwai@suse.de
- Manage dlobj lifetime in pcm_hooks.c
* Wed Jun 24 2009 tiwai@suse.de
- seq_midi_event: fix decoding of (N)RPN events
- MIDI event decoder: prevent running status after sysex
- pcm dmix: fix MIX_AREAS_24 routine for i386 & x86_64 platforms
- Add the support of TLV_DB_MINMAX types
* Tue Jun  9 2009 tiwai@suse.de
- fix breakage of snd_card_load()
- fix SB-Xfi configuration
* Tue Jun  2 2009 tiwai@suse.de
- add configuration for SB X-Fi driver
- extend PCM rate plugin protocol
* Thu May 28 2009 tiwai@suse.de
- adjust more volumes in set_default_volume script
* Wed May 20 2009 tiwai@suse.de
- extend snd_card_get_index() to accept the device path name
* Wed May  6 2009 tiwai@suse.de
- updated alsa-lib to version 1.0.20:
  * including previous fixes
* Tue May  5 2009 tiwai@suse.de
- send SIGTERM then SIGKILL at terminating processes (bnc#486131)
* Thu Apr 23 2009 tiwai@suse.de
- update alsa-lib as of 2009.04.23:
  * pcm: more better documentation for snd_pcm_poll_descriptors
  * pcm_hw plugin: show appl_ptr and hw_ptr in dump() callback
  * pcm_hw plugin: preserve monotonic flag also after
    snd_pcm_hw_params() call
- update alsa-info.sh
* Mon Mar 23 2009 tiwai@suse.de
- fix a typo in joystick init script (bnc#480714)
- add route_policy copy to mono capture hd-audio config
- add sysfs files contents to alsa-info output
* Thu Mar  5 2009 tiwai@suse.de
- Doh, forgot to bump the rpm version number...
* Wed Mar  4 2009 tiwai@suse.de
- alsa-lib git as of 2009.03.03:
  * fix typos in documents
  * change "%%b" semantics for PCM file plugin
- updated alsa-info.sh to ver.0.4.56
* Tue Feb 17 2009 tiwai@suse.de
- set the ctl numids properly with external plugins (bnc#462032)
- fix oxygen driver config (removal of softfloat again)
- increase the preallocated buffer size for HD-audio to improve
  the performance of PA
* Mon Feb 16 2009 tiwai@suse.de
- Fix HD-audio config file (bnc#469886)
* Tue Feb  3 2009 tiwai@suse.de
- Fix the automatic mmap-emul conversion in plug plugin
- Fix off_t in kernel struct
- Fix default PCM for GUS
- New file plugin options
- Fix handling of revents in snd_pcm_poll_descriptor_revents()
* Thu Jan 22 2009 tiwai@suse.de
- updated to version 1.0.19:
  * including previous patches
- fix build without math support
* Tue Jan 13 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Mon Jan 12 2009 tiwai@suse.de
- fix alsasound init script not to unload modules at shutdown
  (bnc#464822, bnc#465389)
* Mon Dec 15 2008 tiwai@suse.de
- Fix the check of ALSA_CONFIG_PATH variable, which caused the
  error in YaST test sound (bnc#440981)
* Thu Dec  4 2008 tiwai@suse.de
- Fix invalid access refine in softvol plugin (bnc#450688)
- Fix the module unloading in alsasound init script without module
  dependency messes; needed for new hd-audio driver
* Wed Nov 19 2008 tiwai@suse.de
- Fix segfault of meter plugin with undefined scope type.
* Wed Nov 19 2008 tiwai@suse.de
- Fix SPDIF configuration for ice1724-based boards (bnc#345421)
- Fix set_default_volume script to use hw:x for avoiding pulse
  plugin, and also accept any value of device name
  (related bug bnc#444349)
* Thu Nov 13 2008 tiwai@suse.de
- check /etc/asound.state before calling alsactl restore
  (related bug bnc#444349)
* Mon Nov 10 2008 tiwai@suse.de
- fix a long-standing mixer bug with global/simple mixer elements
- update README.SuSE
* Wed Oct 29 2008 tiwai@suse.de
- updated to alsa-lib version 1.0.18-final
  just including all previous fixes
- updated alsa-info.sh script taken from the upstream
- use -g option to alsactl to shut off "no card" error messages
* Thu Oct 23 2008 tiwai@suse.de
- add missing declarations of new API functions in pcm.h.
- check /proc/modules instead of lsmod in alsasound script.
* Mon Oct 20 2008 tiwai@suse.de
- add missing iec958 PCM definition for PS3 (bnc#436845)
- fix the bug in device listing (don't show non-existing devices)
- fix some typos in API document
- remove dangerous assert() calls in card control routines
* Wed Oct 15 2008 tiwai@suse.de
- added missing semicolons in init scripts (bnc#435504, bnc#435515)
* Wed Sep 10 2008 tiwai@suse.de
- updated to version 1.0.18rc3:
  * fix the access type handling in softvol plugin
  * add snd_pcm_avail() and snd_pcm_avail_delay()
  * fix SND_PCM_* flags in non-blocking mode
* Fri Aug 22 2008 tiwai@suse.de
- clean up obsolete post scripts
* Mon Aug 18 2008 mrueckert@suse.de
- remove outdated options in the fillup_and_insserv call
* Mon Aug 18 2008 tiwai@suse.de
- fixed required-stop of joystick init script
- remove obsolete joystick control parameters from sysconfig and
  init script
- updated to alsa-lib 1.0.17a -- just including previous fixes
* Wed Aug  6 2008 tiwai@suse.de
- fix the detection of non-interleaved format in dmix code
- fix the detection of old timer tread support in dmix
- update IEC958 status bits for recent additions of consumer mode
- move alsa-info.sh to sbindir
* Mon Jul 28 2008 tiwai@suse.de
- fix snd_pcm_rewind() and snd_pcm_forward() for plugins,
  mainly for pulseaudio
* Wed Jul 16 2008 tiwai@suse.de
- fix baselibs.conf (remove alsa.rpm)
- add a mute-switch function to softvol
- fixed zero-division errors in softvol
* Tue Jul 15 2008 tiwai@suse.de
- updated to version 1.0.17-final:
  * including previous patches
* Wed Jun 18 2008 tiwai@suse.de
- updated to version 1.0.17-rc2:
  * including previous fixes
- updated alsa-info.sh:
  * fixed URL of alsa-info.sh
* Sat Jun  7 2008 tiwai@suse.de
- fix segfault with dmix when 3-bytes formats are used
  (bnc#398265)
* Fri Jun  6 2008 tiwai@suse.de
- fix mmap conversion in plug plugin (bnc#397523)
- fix alsa-info.sh to check whether pastebin is down
* Wed Jun  4 2008 rodrigo@suse.de
- Removed patch to alsa.conf, to not force PulseAudio on all
  apps (ie, non-GNOME installs) (bnc#394177)
* Mon May 26 2008 rodrigo@suse.de
- Add alsa-asound-pulse-conf.diff to include asound-pulse.conf in
  alsa.conf (bnc#394177)
* Fri May 23 2008 tiwai@suse.de
- misc fixes (typo, stsderr out, distro checks) in alsa-info.sh
- initialize the volume first for any possible new volume
  elements by the alsa-driver update (bnc#330409, bnc#392321)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Fri Mar 14 2008 tiwai@suse.de
- HG snapshot 2008314:
  * improve file plugin ifile support
* Mon Mar 10 2008 tiwai@suse.de
- HG snapshot 20080310:
  * fix build with older glibc
  * fix the silence at the beginning of dmix playback
  * hdmi pcm definition (experimental)
  * fix name listing for non-existing devices
- improved/fixed alsa-info.sh for non-HD devices
* Mon Mar  3 2008 tiwai@suse.de
- fix a typo in configure option --enable-symbolic-functions
- HG version (20080228):
  * make doxygen.cfg dynamically (for other build source dir)
  * snd_seq_client_*_event_filter() API
  * Add surround7.1 config for Nvidia
  * iatomic.h for SH arch
* Wed Feb 13 2008 tiwai@suse.de
- fix the build of old programs that don't define *_OLD_API
  properly
* Fri Feb  8 2008 tiwai@suse.de
- updated to version 1.0.16-final:
  * just a version bump
- add alsa-info.sh for debugging purpose.
* Thu Jan 31 2008 tiwai@suse.de
- updated to version 1.0.16rc2
  * including the previous fixes
- deprecate run_ldconfig
* Wed Jan 23 2008 tiwai@suse.de
- fix documentation build (removed obsolete entries)
- fix dsnoop and dshare auto-configuration
* Tue Jan 22 2008 tiwai@suse.de
- updated to version 1.0.16rc1:
  * just a version bump
* Mon Jan 14 2008 tiwai@suse.de
- updated to 2008.01.12 Hg version:
  * Changed SND_PCM_TSTAMP_ENABLE
  * Fixed SND_PCM_TSTAMP_MMAP incompatibility
  * Fixed memory leaks
  * Support dmix rewind
* Wed Jan  9 2008 tiwai@suse.de
- updated to 2008.01.09 HG version:
  * Fix dlsym version error in plugins
  * New monotonic timestamp functions
  * Obsolete PCM xfer_align, sleep_min APIs
* Fri Dec 14 2007 tiwai@suse.de
- updated to 2007.12.14 HG version:
  * revert aliasing in format conversions, which is rather
    problematic
  * add a new API for ioplug PCM (for pulse plugin)
* Thu Dec 13 2007 tiwai@suse.de
- updated to 2007.12.13 HG version:
  * Fix segfault with softvol plugin
  * Add support U8 format with dmix
* Fri Nov 30 2007 tiwai@suse.de
- updated to 2007.11.30 HG version
  * Fix Versions file to reduce unneeded exported symbols
  * fix NULL name strings in pcm plugins
  * fix error codes in card probing
* Fri Nov 23 2007 tiwai@suse.de
- fix possible CPU hog problem with too small avail_min
- fix time-stamp with dmix/dsnoop plugins
- fix mmap of multi plugins
* Fri Nov 16 2007 tiwai@suse.de
- fix the wrong error codes in dmix (#339507)
* Mon Nov 12 2007 tiwai@suse.de
- fix poll_descriptors hack in rate plugin that causes many XRUNs
- fix the calculation of value ranges in alsa-lib simple mixer
  layer
* Mon Nov  5 2007 tiwai@suse.de
- fix ioplug plugin (for pulse or others) to adjust period hw
  params properly.
* Tue Oct 30 2007 tiwai@suse.de
- re-add assert.h to asoundlib.h since some packages got broken
* Mon Oct 29 2007 tiwai@suse.de
- remove unneeded assert from public header files
- remove assert calls in debug routines
- export TLV dB-level parser functions
- fix annoying compile warnings
- remove ac97_bus module at alsasound stop, too
* Tue Oct 16 2007 tiwai@suse.de
- updated to version 1.0.15-final
  * including all previous patches
* Mon Sep 17 2007 tiwai@suse.de
- fix the wrong subdevice number for dmix/dsnoop plugins (#325676)
- fix the handling of "Input Source", to be as a capture element
  (#325677)
- fix use after free in alsa-lib
* Tue Aug 14 2007 tiwai@suse.de
- Add missing pcm_empty.c in doxygen configuration
- seq_midi_event: fix parsing of F9/FD bytes
- seq_midi_event: fix parsing of missing data bytes
- seq_midi_event: prevent running status after system messages
- seq_midi_event: fix encoding of data bytes after end of sysex
* Mon Aug  6 2007 schwab@suse.de
- Fix double free.
* Thu Aug  2 2007 tiwai@suse.de
- fix typos in set_default_volume script
* Mon Jul 30 2007 tiwai@suse.de
- split mmap_emulation plugin from hw layer
- python support (disabled)
- generate asoundlib.h dynamically via configure options
- PS3 configuration
* Wed Jul  4 2007 tiwai@suse.de
- fix the build of lfloat plugin
- allow big-endian with i386/x86-64 dmix
- fix ppc mac configurations for qemu
* Wed Jun 20 2007 tiwai@suse.de
- add missing insserv_cleanup in postun
- add Short-Descriptions tag in init scripts
* Wed Jun 13 2007 tiwai@suse.de
- updated to alsa-lib-1.0.14a:
  just including previous fixes
* Fri Jun  8 2007 tiwai@suse.de
- fix external plugin path, now it's accidentally disabled because
  of a typo in configure script.
- clean up spec file.
* Thu May 31 2007 tiwai@suse.de
- updated to version 1.0.14-final
  * including the previous HG fixes
* Thu May 24 2007 tiwai@suse.de
- HG patch as of 2007.05.24:
  * configure options to specify config and plugin paths
  * dB gain with softvol plugin
  * digital capture softvol for hda-intel (for digital mic)
  * enable slowptr option for dmix as default
* Wed May  2 2007 tiwai@suse.de
- updated to version 1.0.14rc4:
  including previous HG fixes
* Tue Apr 17 2007 tiwai@suse.de
- move soundfont-related stuff to awesfx package
* Tue Apr 17 2007 aj@suse.de
- Fix requires of alsa.
* Mon Apr 16 2007 tiwai@suse.de
- split library files to libasound2 sub package
- split alsa-utils and alsa-oss to own sub packages
- remove static library and unneeded files
* Tue Apr 10 2007 tiwai@suse.de
- update alsa-lib & utils 20070410 snapshot
  * add missing smixer.conf file
  * show iec958 status contents via amixer
  * symbolic-functions build (not enabled yet)
- add alsa-plugins to Recommends tag for a better rate converter
* Thu Mar 29 2007 tiwai@suse.de
- add ncurses-devel to BuildRequires
- update alsa-lib 2007.03.28 snapshot
  * fix shared lib builds
  * more confined plugin selections
  * use speexrate as the default plugin if available
* Wed Mar 14 2007 tiwai@suse.de
- update alsa-lib-1.0.14rc3
  * include last fixes
  * fix ladspa none policy
  * initialize dl handles where needed
  * fix error code in timer_query
  * fix compile warnings
  * add support for symbol prefixes in shlib
  * add card_name function
  * enable dmix for usb-audio
  * multi-plugin fixes from HG version
- update alsa-utils-1.0.14rc2
  * include last fixes
- fix LFS ops on alsa-oss wrapper
* Fri Jan 26 2007 tiwai@suse.de
- fix file lists (#238223)
  * don't include unnecessary static libraries for libaoss
  * don't include libasound.so to the main package
* Tue Jan  9 2007 tiwai@suse.de
- Add empty Should-Start to alsasound init script (#231674)
- Fix compilation of alsa-lib with non-versioned symbols
- Fix LADSPA plugin with multi-channels
- Fix error handling in timer code
- Improved man page of aconnect
* Tue Dec 19 2006 tiwai@suse.de
- update to ALSA 1.0.14rc1:
  * device enumeration API
  * fix dmix/dsnoop memory leaks
  * fix various warnings
* Mon Oct 30 2006 schwab@suse.de
- Revert part of last change.
* Thu Oct 26 2006 schwab@suse.de
- Work around misuse of libtool.
- Fix LDFLAGS.
* Thu Oct  5 2006 tiwai@suse.de
- updated to ALSA 1.0.13-final:
  * all patches have been merged
  * fix inifinite-loop with alsa-lib config alias
* Thu Sep 21 2006 tiwai@suse.de
- updated to ALSA 1.0.13rc2:
  * alisp disablement in configure
  * TLV dB-range support
  * fix some bugs in dB calculation
- fix dB scale check for older alsa-driver
- fix the number parsing in alsa-lib configuration
- use dB expression in alsaconf if possible
- remove the deprecated resmgr support
* Fri Sep  1 2006 tiwai@suse.de
- updated to ALSA 1.0.13rc1:
  * support of linear dB scale
  * fix alsaconf for SLES10/SLED10
- use Should-Start instead of Required-Start in alsasound init
  script as olh suggests (#202075)
* Thu Aug 24 2006 tiwai@suse.de
- updated to ALSA 1.0.12-final:
  * fix possible segfaults with invalid TLV entries
  * fix default paths in configure
- fix udev rules to use DRIVERS= instead of DRIVER=.
* Wed Aug 16 2006 tiwai@suse.de
- Move 52-usx26audio.rules to alsa-firmware package since it
  makes sense only with the firmware files.
* Thu Aug 10 2006 tiwai@suse.de
- Move all rules for usx2y audio to 52-usx2yaudio.rules.
  Use SUBSYSTEM=="usb_device" to avoid the messing order of
  usb detection.
* Tue Aug  8 2006 tiwai@suse.de
- fixed syntax errors in 52-usx2yaudio.rules.
* Mon Aug  7 2006 tiwai@suse.de
- fixed udev script for usx2y drivers.
  provided in a separated 52-usx2yaudio.rules because it must be
  invoked after 50-udev-default.rules.
- fixed the build with the recent gettext.
* Fri Aug  4 2006 tiwai@suse.de
- updated to version 1.0.12rc2:
  * merged previous patches
  * add support of dB range
  * completely removal of dependency to kernel headers
  * config files for new drivers
* Mon Jul 10 2006 tiwai@suse.de
- Added missing invocation of usx2yloader for Tascam USB
  devices in udev rules (#190172).
* Thu Jul  6 2006 tiwai@suse.de
- add --datadir to configure to avoid the invalid datadir with
  recent auto-tools.
* Tue Jul  4 2006 tiwai@suse.de
- updated to version 1.0.12rc1:
  * fix card configurations for ice1724 boards
  * fix division-by-zero in alsa-lib
  * initialize fully the slave PCM in dmix/dsnoop
  * fix segfault with invalid bonding parameter in dmix
  * fix manpages
  * improved output of amidi -l
* Tue Jun 20 2006 dmueller@suse.de
- build parallel
* Mon May 29 2006 tiwai@suse.de
- added the support of delay callback in alsa external I/O
  plugin (for new polypaudio support)
- fix the return value of snd_hctl_wait()
- fix surround40 PCM configuration for ens1370 cards
- added infile option for alsa-lib pcm file plugin
* Wed May 17 2006 tiwai@suse.de
- fix endless loop bug in arecord, also code clean-up.
* Mon May 15 2006 tiwai@suse.de
- update to ALSA 1.0.11-final + HG fixes.
  * all patches in SL10.1 have been merged
  * external rate plugin SDK
  * fix of kernel API for embedded systems
  * new dmix code using O_APPEND open mode
  * misc fixes for sequencer API
  * fix missing dlclose in various plugins
* Thu Apr 27 2006 tiwai@suse.de
- fix segfault with direct plugins when invalid channel binding
  parameters are given.
- fix CPU hog by artsd together with rate plugin.
* Mon Apr 24 2006 tiwai@suse.de
- fix udev rules to use "==" instead of "=".
* Wed Apr 12 2006 tiwai@suse.de
- revert a part of the last fix for aoss, which is rather harmful
  for apps like bmp (#165555)
* Mon Apr  3 2006 tiwai@suse.de
- fix skipping sounds with dmix on aoss (#162771, #162442)
- fix stutering playback of KDE sounds (#162261)
* Wed Mar 29 2006 tiwai@suse.de
- fix the bogus -EPIPE detection (and thus may lead to hang up)
  in 32bit compat mode (ALSA bug#1938).
- correct a typo in the help text of speaker-test
* Fri Mar 24 2006 tiwai@suse.de
- fix the endless poll() loop without starting PCM
- fix the noisy output and xrun from dmix with 2 periods
- fix the broken period/buffer size handling in speaker-test
- fix the parse of lspci output in alsaconf.
* Tue Mar 21 2006 tiwai@suse.de
- fix the wrong read size with 32bit apps on 64bit kernel
  (#159308)
- fix the buffer-size restriction of dmix (#114745)
- fix generic dmix conversion code (mainly for ppc)
- fix alsasound init script to close device files properly
  (#157977)
* Mon Mar 20 2006 tiwai@suse.de
- fix the possible double free in pcm rate plugin (ALSA
  bug#1937)
- fix surround40/51 PCMs (ALSA bug#1914)
- fix the restoration of the original open mode in hw PCM,
  resulting in CPU hog with emu10k1 (ALSA bug#1938)
- fix hw-constraints in extplug plugin, added init callback
* Mon Mar 13 2006 tiwai@suse.de
- added $LOAD_OSS_SEQ_MODULE in sysconfig/sound for (optional)
  auto-loading of snd-seq-oss (#155332).
- fix bugs in drain with PCM rate plugin (taken from upstream).
* Fri Mar  3 2006 tiwai@suse.de
- Fix from upstream: fix the return value to -ENODEV from
  - ENOTTY in alsa-lib functions when the device is
  disconnected.
* Thu Mar  2 2006 tiwai@suse.de
- fix segfault with PCM rate plugin (ALSA bug#1878)
- fix speaker-test with 5.1 channels
* Mon Feb 27 2006 tiwai@suse.de
- fixed close functions in the disconnected state, resulting in
  invalid states and memory leaks.
- fixed a typo in sequencer (possible memory leak).
* Mon Feb 20 2006 tiwai@suse.de
- avoid unnecessary call of resmgr (#145934)
* Mon Feb 20 2006 tiwai@suse.de
- fixed the infinite loop of snd_pcm_wait due to XRUN (#149894)
- fixed the compile warning on 64bit arch.
* Fri Feb 17 2006 tiwai@suse.de
- fix the assert with float conversion (#149894).
- fix full-duplex confliction with dmix/dsnoop plugin.
- fix the default behavior of non-blocking open mode.
* Wed Feb  8 2006 tiwai@suse.de
- fixed small memory leaks in the alsa-lib parser.
- fixed a typo in rawmidi_virt plugin.
* Mon Jan 30 2006 tiwai@suse.de
- fixed alsasound script for the first yast2 config (#145934)
* Mon Jan 30 2006 tiwai@suse.de
- fixed the segfault at parsing recursive definitions and the
  handling of the string slave of direct PCM plugins (#146447)
* Fri Jan 27 2006 tiwai@suse.de
- removed invalid assert in alsa-lib
- fixed ladspa plugin in alsa-lib
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 tiwai@suse.de
- Fix the non-blocking open mode (used non-blocking open mode as
  default, too)
- Support of multiple cards/devices with direct plugins
* Thu Jan 12 2006 tiwai@suse.de
- PCM simple helper functions
- ICE1712 conf to use dmix/dsnoop
- Fix S24_BE format
- Fix mixer switch handling in aoss
- Improved alsasound script for restarting/reloading
* Wed Jan 11 2006 tiwai@suse.de
- Fix a typo in load-soundfont script (#141761)
* Mon Jan  2 2006 tiwai@suse.de
- updated to version 1.0.11rc2.
* Wed Dec 14 2005 tiwai@suse.de
- updated to version 1.0.11rc1.
* Fri Nov 25 2005 tiwai@suse.de
- Move udev rules to alsa package.
* Wed Nov 23 2005 tiwai@suse.de
- updated to version 1.0.10-final.
- CVS patches as of 2005.11.23.
- fixed a typo in alsasound script.
* Tue Nov  8 2005 perex@suse.de
- updated to version 1.0.10rc3
- changed --with-prefix to --prefix
- removed RPM_BUILD_ROOT cleanup from %%install
* Thu Oct 27 2005 tiwai@suse.de
- Update to CVS 2005.10.27.
  - fixed PCM mmap mode with plugins.
  - optimize / improve aoss wrapper.
  - improve aplay/arecord option parsing.
- Fix alsasound init script.
* Wed Oct 12 2005 tiwai@suse.de
- updated to version 1.0.10rc2.
* Thu Sep 29 2005 tiwai@suse.de
- Fix type-punning with the latest gcc
- Mute volume at shutdown (#117277)
* Wed Sep 14 2005 tiwai@suse.de
- Fix bugs of dmix on big-endian architectures (#117048)
  - Fix the argument of semctl() with union.
  - Fix the mixing code, accepts both endians.
  - Fix alsa-lib configurations.
- Fix hwcfg file name generated by alsaconf (#117046).
* Mon Sep 12 2005 tiwai@suse.de
- Fix the error with chown() in direct plugins when the user
  doesn't belong to the group (#115817).
- Fix segfault of PCM hooks plugin (#116568)
- Load snd-seq module if requested (#116557).
- Fix uninitialized pollio variable in pcm.c.
* Thu Sep  8 2005 tiwai@suse.de
- Fix the permission of socket of direct plugins (#115817)
- Fix the modem definition on hda-intel (#115253)
* Fri Sep  2 2005 tiwai@suse.de
- Fix the internal buffer allocation of alsa-lib plugins,
  including the fix for ICE1724 config (#115019)
* Fri Sep  2 2005 tiwai@suse.de
- Fix aoss with bi-arch (#114961)
* Thu Sep  1 2005 tiwai@suse.de
- Fix PM resume with aoss (#114690)
* Wed Aug 31 2005 tiwai@suse.de
- Fix crash of knotify (#105772)
* Fri Aug 26 2005 tiwai@suse.de
- fixed alsasound restart (#113239)
- fixed the handling of -EINTR during resume of dmix (#104100)
- fixed the buffer size of speakertest (ALSA BTS #1304)
- fixed isapnp detection of alsaconf (ALSA BTS #1326)
- added a description about new init script
* Thu Aug 18 2005 tiwai@suse.de
- Fix invalid read warnings detected by valgrind2 (#105572)
* Thu Aug 18 2005 tiwai@suse.de
- Fixed races in direct plugins (#104884)
- Fix/clean up aoss wrapper
- Fixed memory leak in alsa-lib pcm configuration
* Tue Aug 16 2005 tiwai@suse.de
- fix PM of direct plugins (#104100)
* Fri Aug 12 2005 tiwai@suse.de
- fix biarch problem with dmix (#104424)
- fix default IPC permissions to 0660
* Wed Aug 10 2005 tiwai@suse.de
- fixed segfault of aoss (#103780)
- take back alsa udev script for soundfonts (#103814)
- fixed probing of isapnp devices
* Fri Aug  5 2005 tiwai@suse.de
- fix alsaconf to set up hwcfg-* to follow the new sound system
  on SL10.0.
* Wed Aug  3 2005 tiwai@suse.de
- update to ALSA cvs 2005.08.03.
- removed obsolete usb map stuff.
- removed resmgr dev scripts.
- modified alsasound init script to do minimal jobs in start/stop.
  reload/unload are used to force module-reloading.
* Mon Jun 27 2005 tiwai@suse.de
- added resmgr to Requires of alsa-devel to make the build checker
  script easier.
* Thu Jun  2 2005 tiwai@suse.de
- updated to version 1.0.9-final.
- CVS updates 2005.06.02
* Tue May 24 2005 tiwai@suse.de
- updated to version 1.0.9rc4.
* Fri May 20 2005 tiwai@suse.de
- CVS 2005.05.20: fixes permissions and dmix stuff.
* Tue May 17 2005 tiwai@suse.de
- CVS 2005.05.16: more fixes on dmix and rate plugins.
* Fri May 13 2005 tiwai@suse.de
- updated to version 1.0.9rc3.
* Wed Apr 20 2005 tiwai@suse.de
- fix segfault of rate plugin.
- change the value of $LIBASOUND_DEBUG to integers.
* Fri Apr  8 2005 tiwai@suse.de
- another try to fix dmix hang-up bug.
* Tue Apr  5 2005 tiwai@suse.de
- added the large-file support on alsa-oss wrapper.
- fixed dmix hang-up problems.
- fixed the wrong channel_info on some plugins.
* Fri Apr  1 2005 tiwai@suse.de
- updated to ALSA 1.0.9rc2.
- fixed compilation with gcc-4.0.
* Wed Mar 16 2005 tiwai@suse.de
- Fixed default "front" volume (bug #72971)
- Fixed the device-open check for sequencer (bug #72368)
* Tue Mar 15 2005 tiwai@suse.de
- fixed suspend/resume with dmix, dsnoop, dshare plugins
  (#72780)
* Fri Mar 11 2005 tiwai@suse.de
- Fixed wrong memory free in alsa-lib.
- Addition of a new user-control API function for external PCMs.
- Fixed documents of external PCM plugins.
- Fixed Aureon 7.1 configuration.
- Minor fixes for valgrind.
- Fixed the segfault with PCM file plugin.
- Addition of missing sequencer macro.
- Fixed typos in iecset.
* Thu Feb 24 2005 tiwai@suse.de
- fixed the card type for each config with softvol.
- got rid of debug prints in udev scripts (bug #66476)
* Tue Feb 22 2005 tiwai@suse.de
- use ncursesw for alsamixer
- fixed distribution check in alsaconf
- split aseqdump from arecmidi
- fixed man pages
- try to modprobe always in alsasound init script at start
- updated alsasound.usermap.
* Fri Feb 18 2005 tiwai@suse.de
- CVS patch 20050218:
  - fix speaker-tools
  - fix the weight of Side mixer elements
  - use softvol as default for VIA823/8237
- fixed resmgr support (a typo in configure options).
* Wed Feb 16 2005 tiwai@suse.de
- fixed amidi command options.
- fixed configure option for shared alsa-lib.
- fixed the path of resmgr.
* Mon Feb 14 2005 tiwai@suse.de
- CVS patch 20050214:
  - disable access to /dev/aload*
  - external filter-plugin SDK
  - dl-object cache
- Initialize hardware via hotplug/udev
  alsactl, etc are called in dev.d/* scripts
* Fri Feb 11 2005 tiwai@suse.de
- CVS patch 20050211:
  - fixed resmgr support, enable it as default
  - external PCM I/O plugin support
* Fri Feb  4 2005 tiwai@suse.de
- CVS patch 20050204:
  - fixed segfaults with mixer event handling.
* Wed Feb  2 2005 tiwai@suse.de
- CVS patch 20050202:
  - fixed function-in-function
  - fixed exit code of alsa-utils programs
* Thu Jan 27 2005 tiwai@suse.de
- CVS patch 20050127:
  - dmix and dsnoop for default PCMs on many chips
  - pcm link fix
  - resmgr support (not enabled yet, waiting for fix in udev)
* Tue Jan 18 2005 tiwai@suse.de
- include fixes for alsa-lib and alsa-utils from CVS.
* Thu Jan 13 2005 tiwai@suse.de
- updated to version 1.0.8-final.
* Mon Jan  3 2005 tiwai@suse.de
- updated to version 1.0.8rc2.
* Wed Nov 17 2004 tiwai@suse.de
- updated to version 1.0.7.
* Thu Sep 30 2004 tiwai@suse.de
- unmute/adjust 'Master Mono' in alsaconf as default.
* Thu Sep 30 2004 tiwai@suse.de
- fixed segfault when printing help of aserver.
- fixed card-specific include files in alsa-lib.
- fixed ICH4 SPDIF support.
- fixed card aliases.
- fixed segfault when configuring the invalid sw_params.
- fixed shadow parameters in alsa-lib headers.
- fixed the handling of config files in alsaconf.
- fixed manpages in alsa-utils.
* Thu Sep 16 2004 tiwai@suse.de
- fixed downsampling.
- fixed the error handling in dmix plugin.
- fixed alsa.m4 to avoid invalid reductions in $LIBS.
- fixed aplay for large file I/O and VOC file playback.
* Mon Sep 13 2004 tiwai@suse.de
- fixed the infinite loop in alsa-lib parser.
* Tue Aug 31 2004 tiwai@suse.de
- fixed alsaconf probing and options.
- fixed usb usermap for snd-usb-usx2y driver.
* Fri Aug 27 2004 tiwai@suse.de
- updated to 1.0.6 final.
- added the new supported card config files.
- support the seprate playback/capture view on alsamixer.
- don't load snd-seq-oss in alsasound script.
* Thu Aug 12 2004 ro@suse.de
- added libpng to neededforbuild (for doxygen)
* Thu Aug  5 2004 tiwai@suse.de
- updated to 1.0.6rc1.
- Clean up alsasound init script.
* Thu Apr 15 2004 tiwai@suse.de
- updated to version 1.0.4.
- fixed ACPI suspend/resume handling (#38571).
- removed the obsolete %%post stuffs.
- removed the unneeded sleep in alsasound.
- fixed the handling of '-' and '_' letters in module names.
* Fri Apr  2 2004 kukuk@suse.de
- alsasound: Fix Start/Stop Requires
* Mon Mar 29 2004 tiwai@suse.de
- fixed REAME.SuSE.
- fixed the SPDIF output of Nforce.
- fixed snd_pcm_wait() for direct plugins.
- fixed the rate plugin to mangle avail_min.
- fixed the wrong copy problem in capture of rate plugin.
- fixed the closing bug of alsa-oss.
- fixed the pcm handling in alsa-oss.
- updated usb audio map.
* Fri Mar 19 2004 tiwai@suse.de
- fixed alsaconf for the legacy chip probing (#36256).
- fixed alsaconf for the dell board.
- fixed aplay/arecord for largefile support.
- improved the PCM polling.
- fixed segfaults in dmix codes.
- included some h/w specific headers into alsa-lib.
- fixed mono output definitions in emu10k1 configs.
* Mon Mar  8 2004 tiwai@suse.de
- updated to alsa-lib 1.0.3a.
* Mon Mar  1 2004 tiwai@suse.de
- updated to alsa-oss 1.0.3a.
* Mon Mar  1 2004 tiwai@suse.de
- 1.0.3-final package.
* Fri Feb 27 2004 tiwai@suse.de
- use asfxload for emu10k1 and sbawe scripts.
- added sleep in alsasound to get sync with device files.
- added LOAD_OSS_EMUL_MODULES in sysconfig/sound.
- alsa-oss 1.0.3rc3.
* Thu Feb 26 2004 tiwai@suse.de
- updated to version 1.0.3rc2.
- regenerated usb usermap.
* Thu Feb 12 2004 tiwai@suse.de
- updated to version 1.0.2.
- fix for stripping RPATH from libaoss (thanks to kraxel's script).
* Fri Jan 16 2004 pth@suse.de
- Fix quoting in alsa.m4
* Mon Jan 12 2004 adrian@suse.de
- build as user
* Fri Jan  9 2004 tiwai@suse.de
- updated to version 1.0.1.
* Mon Nov 17 2003 tiwai@suse.de
- updated to version 1.0.0pre1.
  now new API is used as default.  the apps with old API should
  define ALSA_PCM_OLD_HW_PARAMS_API and ALSA_OLD_SW_PARAMS_API
  to keep using the old-style API.
* Wed Sep 17 2003 tiwai@suse.de
- fixed the broken dmix plugin with 32bit samples.
- implemented the dmix plugin for x86-64.
- apply the last missing patch.
* Mon Sep 15 2003 tiwai@suse.de
- don't remove joydev in joystick script (bug #30661).
* Thu Sep 11 2003 tiwai@suse.de
- fixed the rate conversion plugin.
- fixed the aplay to set up correctly with unconventional rates.
- fixed the manpage of aplay and arecord.
- fixed the range calculation overflow in alsamixer.
* Mon Sep  8 2003 tiwai@suse.de
- fixed dmix, dshare, dsnoop plugins.
- fixed alsaconf for the recent modutils.
* Mon Sep  1 2003 tiwai@suse.de
- fixed config files for audigy boards.
* Wed Aug 27 2003 tiwai@suse.de
- fixed the wrong name (typos) of snd_seq_port_info_timestamp
  functions.
- added MEMORY-LEAK note.
* Thu Aug 14 2003 tiwai@suse.de
- rewrite alsasound init script to accept reload for reloading
  the sysconfig changes.
- added meta data to sound and joystick sysconfig files
  (bug #28941, #28887).
* Wed Aug 13 2003 tiwai@suse.de
- updated alsa-lib to 0.9.7-pre (cvs 2003.08.13)
- updated usb usermap.
* Tue Aug  5 2003 tiwai@suse.de
- fixed lsmod path (bug #28430).
* Thu Jul 31 2003 meissner@suse.de
- Adapted symbol version defines for ppc64 (should be reusing the
  macro mess from glibc though).
* Wed Jul 30 2003 tiwai@suse.de
- removed unsued binary file the filelist.
- added the fix for via82xx renaming.
- clean up the post-install code.
- added post_on_removal and restart_on_update for alsasound and
  joystick services.
* Mon Jul 28 2003 tiwai@suse.de
- updated to version 0.9.6.
* Fri Jul 18 2003 tiwai@suse.de
- updated to version 0.9.5.
- fixed alsasound and alsaconf for the new modutils.
* Fri Jul  4 2003 tiwai@suse.de
- updated to version 0.9.4.
- fixed the option of head command in alsa-scripts (bug #27413).
- updated alsaconf; -p shows the card name, too.
* Fri Jun 13 2003 ro@suse.de
- added /etc/hotplug and /etc/hotplug/usb to filelist
* Tue May 27 2003 ro@suse.de
- add static libaoss to filelist of devel subpackage
* Tue Apr 15 2003 tiwai@suse.de
- fixed the option of head command in the new POSIX way.
* Mon Mar 17 2003 tiwai@suse.de
- fixed alsaconf to run for suse modules (bug #25440).
- don't unload soundcore and gameport modules in alsasound
  init script - they may be used by other services/devices
  (bug #24091).
* Mon Mar 10 2003 tiwai@suse.de
- fixed arecord to write a better WAV file header for stdout
  (bug #24845).
* Wed Mar  5 2003 tiwai@suse.de
- try to restore the old style elements (cardX) even after the id
  is changed.  this will prevent the silent state after updating
  the package.
- fixed the feedback address in README.SuSE.
* Mon Feb 24 2003 tiwai@suse.de
- added -F option to alsactl in alsasound init script.
* Thu Feb 20 2003 tiwai@suse.de
- don't use nested functions on non-ix86 architectures.
* Mon Feb 17 2003 tiwai@suse.de
- updated to cvs20030217.
  including dmix plugin support.
- mute the master volume at unloading to avoid clicks.
* Fri Feb  7 2003 tiwai@suse.de
- updated to cvs20020307.
- fixed aplay bug.
- added the support of new timer interface.
- updated usb map.
* Wed Jan 29 2003 tiwai@suse.de
- fixed the versioned symbols of hook pcm and meter plugins.
- fixed -d option of aplay.
* Tue Jan 21 2003 tiwai@suse.de
- fixed the dlopen for hook, ladspa and meter pcm plugins.
- added configuration files for ENS1371 and VIA8233.
- fixed the handling of 24bit/3bytes samples.
- updated USB usermap.
* Thu Jan 16 2003 tiwai@suse.de
- added the metadata to sysconfig files (bug #22689).
* Wed Dec 18 2002 tiwai@suse.de
- updated to 0.9.0rc7-pre; regenrated tarballs from cvs.
- regenerated usb usermap.
- removed patches.tar.bz2.  patches will be listed on spec.
- added SOUNDFONT_FILES in sysconfig/sound, which is used in sbawe
  and emu10k1 init scripts (bug #21622).
- removed alsa-dummy library, since KDE2 is no longer supported.
- removed alsa-kernel header files from devel sub-package.
  alsa-tools will include the necessary header files in itself.
* Fri Dec 13 2002 tiwai@suse.de
- fixed the build with the latest automake & co.
* Mon Nov 11 2002 ro@suse.de
- fix deprecated multiline string literal in aplay.c
* Tue Sep  3 2002 tiwai@suse.de
- alsactl tries to restore the mixer elements as much as possible.
  this will avoid "failure" status of alsasound after a driver is
  updated.  (bug #18823)
- fixed invalid use of assert in mixer.
- probe more possible dmas for cs and es18xx cards in alsaconf.
- load snd-usb-midi module additionally if necessary in alsa usb
  script.
* Thu Aug 29 2002 tiwai@suse.de
- fixed hotplug start script.
- fixed wrong assertion in alsa-lib.
- added the support for 24bit wav and new options -C and -P
  to aplay.
* Fri Aug 23 2002 tiwai@suse.de
- added the hotplug usermap and script files (bug #16768).
* Tue Aug 20 2002 tiwai@suse.de
- fixed the detection of powermac driver on alsaconf.
* Fri Aug 16 2002 tiwai@suse.de
- use the rc3 tarballs (meaning only version up).
- fixed alsa-lib's configure to get the newest auto-tools running.
- updated the comments on power management.
* Wed Aug 14 2002 tiwai@suse.de
- fixed X-UnitedLinux-Should-Start in init script.
* Thu Aug  1 2002 tiwai@suse.de
- added PreReq.
- improved alsa-lib documentations.
- fixed alsaconf for redhat :)
- added windows' path for soundfonts on emu10k1 script.
- provides scripts for more cards with opl3.
* Sat Jul 27 2002 adrian@suse.de
- add %%run_ldconfig
* Mon Jul 22 2002 tiwai@suse.de
- fixed 3byte format conversion in plugins.
- fixed route pcm plugin.
  fixed calculation of norm.
* Tue Jul 16 2002 meissner@suse.de
- Fixed lib64 problem (/usr/lib was not created on lib64 platforms,
  but is used for data files).
* Mon Jul 15 2002 tiwai@suse.de
- split gamix and alsa-tools as individual packages.
- removed unused files from package sources.
- fixed 3byte format access and unsigned linear conversion
  plugins on alsa-lib.
* Wed Jul  3 2002 tiwai@suse.de
- fixed README.SuSE.
- alsaconf builds the card database by itself.
- added -s option to alsaconf to specify the test wav file.
- removed obsolete cardid files on docdir.
* Wed Jun 26 2002 tiwai@suse.de
- changed the format ioctl mask.
  added the backward compatible ioctls.
- don't check the error of running-mode ioctl for backward
  compatibility.
- modprobe snd-ioctl32 in alsasound script.
* Fri Jun 21 2002 tiwai@suse.de
- fixes and enhances for 64bit architectures.
  sequencer has a new ioctl, RUNNING_MODE is used to check the
  running 32/64 bit mode of the client.
* Wed Jun 19 2002 tiwai@suse.de
- moved alsa drivers into kernel-source package.
  this package includes only the header files from alsa-kernel
  tar ball to reduce the size.
  km_alsa is no longer generated.
- support for 3-bytes packed formats (e.g. usb audio 24bit
  format)
* Tue Jun 11 2002 tiwai@suse.de
- version alsa 0.9.0 rc1.
- added new pnp id for cs4236.
- improved rme32 driver.
- fixed resource handling of rme9652 driver.
- added hdsp driver.  snd-rme9652-mem is renamed to
  snd-hammerfall-mem.
- added experimental usb audio driver.
- fixed pmac driver.  added auto-muting support as well as on
  0.5.x driver.
  tone controls and DCR support for tumbler chip.
  tone control and amplifier for screamer chip.
- removed own i2c functions from pmac driver.  now using the
  standard i2c interface and i2c-keywest module.
- added 64bit integer support on control API.
- fixed cs4281 driver.  supporting two codecs experimentally.
- fixed capture of aplay on big endian.
- fixed sysex encoding of sequencer.
- fixed the module counter on gus driver.
- removed EXPORT_NO_SYMBOLS from the code of alsa-kernel.
  moved to alsa-driver for compatibility.
- support of RME9636, RME9652 and GUS configurations.
- fixed the check of return values from copy_*_user().
- fixed via8233 driver to work on via8233A.  using multi-channel
  SGD for playback.
- fixed es1968's hardware volume control.
- added 2ch to 4ch duplication switch to ymfpci.
- added support for spdif on cirrus logic's ac97 codecs.
- fixed Makefile and Config.in for 2.5 kernels.
- removed the obsolete snd_seq_create_event() from sequencer API.
  fixed alsa.m4 for this change.
- fixed detection of ews64 card.
- fixed null pcm plugin.
- added options to set uid, gid and mode of alsa's device files
  to alsaconf script.  as default alsaconf doesn't set such
  options.  for secure set up, call with -r option.
* Tue May  7 2002 tiwai@suse.de
- fixed hardware volume control on es1968.
- optimized rme32 driver.
- more complete naming of ich chipsets.
- fixed rear playback via wave surround on emu10k1.
- fixed trident driver for big endian.
- fixes for 2.2 kernels.
- fixed aplay to play 16bit-au format correctly.
- fixed typo in amixer.
* Fri May  3 2002 tiwai@suse.de
- alsasound sets default volumes for all cards if no asound.state
  is found.
- unmute mic in set_default_volume script.
- integrated via8233 to via686.  via8233 module still exists,
  though.
- fixed emu10k1 on big-endian machines.
- fixed inverted cmi8330 pcm volume.
- support --with-softfloat option to alsa-libs' configure.
- fixed check of include path in alsa-driver's configure.
- fixed compile on alpha.
- added a new control switch to toggle shared rear/line-in on
  ymfpci.
- removed list-muti from Makefile of alsa-kernel.
- fixed compile of powermac drivers.
- fixed possible deadlock of timer module.
- added pcm playback using emu8000 on sbawe driver.
- fixed panning of sbawe's wavetable.
- phone and mic registers can have 5-bit resolution on ac97.
- fixed compile of drivers on 2.2 and early 2.4 kernels.
* Thu May  2 2002 meissner@suse.de
- dropped qt dependencies, are not needed apparently.
* Tue Apr 23 2002 tiwai@suse.de
- fixed deadlock on intel8x0.
- fixed deadlock on ice1712.
- fixed Config.in for alsa-kernel.
- improved detection of cmi8330 chip.
- improved detection of OPL4.
- fixed behavior of midi input on oss sequencer emulation.
- a bit clean up of sequencer core.
- fixed virmidi on sbawe/emu10k1 wavetables.
- clean up alsaconf script.
* Fri Apr 19 2002 tiwai@suse.de
- build alsa static library separately from shared lib
  (due to a bug of libtool).
- moved ipaq driver into alsa-kernel.
- new driver: rme32.
- fixed possible locking on sequencer.
- fixed non-compatible variables (LOAD_ALSA_SEQ).
- invoke soundfont and opl3 scripts only when LOAD_SEQUENCER
  is set.
- fixed duplicated object lists in Makefile.
  (a workaround for make modules_install)
- using new vararg macro on gcc3.
- fixed sound_core.c
- removed ipc code from sequencer.
- fixed capture plugins.
* Tue Apr 16 2002 tiwai@suse.de
- fixed capture on OSS emulation mode.
- fixed digital/analog switch on SB live and audigy.
* Mon Apr 15 2002 tiwai@suse.de
- updated ipaq driver.
* Fri Apr 12 2002 tiwai@suse.de
- fixed build on mips.
* Wed Apr 10 2002 tiwai@suse.de
- install non-stripped binaries as default.
* Tue Apr  9 2002 tiwai@suse.de
- updated gamix to 1.99.p13.
  added pkgconfig to neededforbuild.
- fixed compile drivers on 2.2 kernel.
- added --libdir options to configure to make sure building
  for lib64.
- use dot instead of underscore in the rpm version.
- improved the detection of spdif on ens1371.
- fixed spdif i/o on ewx24/96.
- fixed OSS mmap emulation.
- added the drivers for arm (iPAQ).
- added new pnp id for cs4236.
- fixed arecord to capture raw data.
- added spdif support on wolfson ac97 codec.
- increase the max. number of rawmidi devices to 8.
- added -D option to amixer (just like on alsamixer).
- fixed digital/analog switch for audigy.
- added presario700 workaround on ac97 codec.
- added boot-up script for sb16 to load opl3 files.
* Fri Apr  5 2002 ro@suse.de
- fixed gamix to build with new gettext
* Mon Mar 25 2002 tiwai@suse.de
- fixed spdif-input clock selection on EWX24/96.
* Mon Mar 25 2002 tiwai@suse.de
- added -Y to fillup_and_insserv joystick (bug #15433).
- removed check of joydev module at start of joystick script
  (bug #15441).
- force to proceed even if ac97 not responding (bug #15428).
- fixed clock detection messages on intel8x0.
- support VIA8233 on via686 driver (bug #13786).
* Fri Mar 22 2002 tiwai@suse.de
- real fix for sb16 vibra.  merged forgotten patch.
- fixed aseqnet.
- fixed the use of size_t in sequencer headers.
- fixed alsamixer; no longer aborted on es1938 mixer.
* Wed Mar 20 2002 tiwai@suse.de
- fixed capture on sb16 vibra.
* Tue Mar 19 2002 tiwai@suse.de
- fixed assignment of DMAs on als100 driver.
- removed zero-initialization of static variables to move (to
  data block).
- fixed compile of emu10k1 on 2.2 kernel.
- fixed detection of Delta 1010LT.
- moved description of serial driver to Documentation directory.
* Wed Mar 13 2002 tiwai@suse.de
- corrected texts.
- fixed playback rate on via686 driver.
- clean up via8233 driver.
- improved rate converter again.
* Tue Mar 12 2002 tiwai@suse.de
- more fix for alsa-lib rate converter.
- fixed handling of capture volume/switch on simple mixer API.
  fixed alsamixer, too.
- fixed pci ids for AMD chips.
  cards.txt and cardids.txt are updated, too.
* Mon Mar 11 2002 tiwai@suse.de
- fixed support of vibra16 on sb16 driver.
* Mon Mar 11 2002 tiwai@suse.de
- fixed xrun problems on alsa-lib rate converter.
- fixed pci id definitions for AMD8111.
* Mon Mar 11 2002 tiwai@suse.de
- fixed/clean-up rawmidi driver.
- fixed compile or rtc-timer.
* Sat Mar  9 2002 tiwai@suse.de
- fixed segfault of aplay with a larger wav header.
- clean up emu8000 and wavefront drivers; added __init prefixes.
- fixed capture on audigy.
* Fri Mar  8 2002 tiwai@suse.de
- fixed alsaconf: asound.conf -> asound.state.
* Fri Mar  8 2002 tiwai@suse.de
- fixed segfault in alsa-lib regarding rate conversions.
- don't show colon at start up when no card is configured.
- fixed collision of resources for legacy opl3 and midi in ymfpci
  and cmipci drivers.
- fixed audigy FX capture.
- fixed compile of powermac driver.
- fixed emu10k1 5.1 surround output.
* Thu Mar  7 2002 tiwai@suse.de
- reverted pci quirk code from 0.5.x for opl3sa2 driver.
- fixed es1968, maestro3, ymfpci: don't call
  snd_pcm_period_elapsed() more than once per interrupt.
- removed unused sequencer codes from the source.
- fixed ioctl32 wrapper.
- fixed memory leak in rawmidi.
- return rc 5 (skipped) when no joystick device is configured.
* Wed Mar  6 2002 tiwai@suse.de
- fixed some bugs in gamix.
- use rwlock instead of spinlock in the pcm operation.
- fixed maestro3 driver to avoid picking the modem up.
- fixed module descriptions in wavefront driver.
- remove invalid snd_id module options in alsa post install
  script (bug #14542).
- suppress "unexpected hwpointer.." debug messages (bug
  [#14275]).
- fixed initialization of sequencer midi decoder.
- moved some documents into alsa-kernel directory.
- fixed module depenency descriptions.
- added the arm support (not compiled for rpms).
- moved oss related proc files to /proc/asound/oss.
- fixed floppy-hangup problem on ymfpci driver.
* Wed Feb 27 2002 tiwai@suse.de
- fixed handling of capture volumes/switches in alsamixer.
- added support for x86-64 to alsa drivers' configure script.
- set alsa's header path prior to the kernel headers.
- added ioctl32 wrappers for 64bit architectures (still not
  compiled on existing architecturs).
* Mon Feb 25 2002 tiwai@suse.de
- fixed spdif phase inverse on cmipci for the recent models.
* Mon Feb 25 2002 tiwai@suse.de
- fixed AC3 passthrough on SB Live.
- added support for AMD-8111.
- fixed SPDIF input inverse switch on cmipci.
- added SPDIF input select switch on cmipci (for recent models).
- added Config.help in alsa-kernel.
- use normal printk with KERN prefixes for usual messages
  instead of snd_printk.
- fixed pci_alloc_consistent hack for ppc.
- fixed module depenency in alsa-kernel.
- fixed count overflow problem on aplay.
- fixed legacy isa probing of alsaconf.  now killing aplay/arecord
  with -9.
* Fri Feb 22 2002 tiwai@suse.de
- added -p option to alsaconf to be invoked from external
  programs.
- alsaconf checks TP600E and tries to configure cs4236
  automatically.
- fixed oops on cs423x drivers.
* Fri Feb 22 2002 tiwai@suse.de
- fixed surround and center/lfe (analog) outputs on audigy.
- added snd_mmap_valid option to cs46xx driver to support OSS
  mmap mode.  as default it is disabled (to be sure).
- fixed alsa-lib to adapt the recent API changes.
* Thu Feb 21 2002 tiwai@suse.de
- fixed memory allocation for ISA.
- improved alsa-lib xrun checks.
- fixed audigy driver
  analog front is output through ac97.
  enabled digital outputs.
  fixed ADC capture.
  support for line2 and aux2 inputs.
- fixed volumes of wavetable on emu* drivers.
* Thu Feb 21 2002 tiwai@suse.de
- improved xrun check - a new ioctl is added for xrun.
- llseek lock fixed for 2.5 kernel.
* Wed Feb 20 2002 tiwai@suse.de
- fixed oops on SB Audigy.
- fixed/improved set_default_volume script.
* Wed Feb 20 2002 tiwai@suse.de
- added (partial) midi / joystick support to intel8x0 driver.
- fixed ac97 initialization of via686 driver (bug #13404).
- added set_default_volume script and fixed alsasound init script
  to set up volumes automatically when no config file is found
  (bug #13649).
- fixed module depencies in alsa-kernel.
- added --with-kernel and --with-soundbase options to configure
  scripts in alsa-tools.
- wait for the codec ready status for more longer time in ac97
  driver.
- fixed typos (lockups) in rme9652 driver.
- fixed inverted aux playback switch on cmipci driver.
- added verbose (debug) printk mode.  fixed printk prefixes.
- alsasound script does't show failure messages even if ALSA is
  already running (bug #13614).
* Tue Feb 19 2002 tiwai@suse.de
- fixed spdif on cmipci driver (for the recent chip models)
* Tue Feb 19 2002 tiwai@suse.de
- configurable verbose level of messages in alsa-driver.
- fixed isa memory allocation for old codes.
- fixed error handling of sequencer core.
- added/fixed include files for correct compile.
* Mon Feb 18 2002 tiwai@suse.de
- fixed joystick init script.
- fixed es18xx driver to support pm correctly.
* Mon Feb 18 2002 tiwai@suse.de
- fixed intel8x0 driver for nVidia nForce.
* Mon Feb 18 2002 tiwai@suse.de
- fixed renaming/moving of LOAD_ALSA_SEQ variable to sysconfig
  (Bug #13941)
- fixed endian check in the kernel.
- revert to the old isa allocator code.
- fixed power management codes.
- fixed obsolete usage of __FUNCTION__.
- fixed compile on ppc64.
- check the compile date in configure script.
* Fri Feb 15 2002 tiwai@suse.de
- support for ppc64.
- use pci_alloc_consistent for allocation of ISA buffers.
* Fri Feb 15 2002 tiwai@suse.de
- fixed compile on 2.5.5 kernel.
- fixed typo in pcm_preallocate_all().  now should be built on
  ia64.
* Thu Feb 14 2002 tiwai@suse.de
- more alsa-lib document fixes/improvements.
- fixed build of alsa-driver on the latest alpha kernel.
* Wed Feb 13 2002 tiwai@suse.de
- building drivers with debug option.
- fixed wrong kfree's after release_resource().
- fixed possible collision of macros with ACPI patches.
- moved joystick support from module option to controls in
  ymfpci and via686 drivers.
- removed snd_enable_midi option from es1968 driver.
  mpu401 is enabled as default.
- fixed initialization of joystick address in joystick init
  script.
- more docuemnts for timer releated issues in alsa-lib.
* Tue Feb 12 2002 tiwai@suse.de
- fixed mixer volumes on ad1816a.
- fixed playback/capture on ad1816a.
* Mon Feb 11 2002 tiwai@suse.de
- clean up module descriptions for yast2.
- fixed memory leaks before release_resources.
- introduced isa_virt_to_bus macro.
- fixed swap bugs in korg1212 driver.
- compilation fixes for sequencer-related modules.
- moved compatibility layer code to alsa-driver.
- fixed es1968 suspend/resume code.
- make sure intel8x0 driver working on non-intel archs.
* Fri Feb  8 2002 tiwai@suse.de
- fixed mpu401 handling and wave table devices on audigy.
- fixed mpu401 interrupts on ymfpci.  snd_mpu_irq options is
  removed.
* Thu Feb  7 2002 tiwai@suse.de
- fixed compile of pmac driver.
- added hack for panasonic CF-28.
- fixed handling of irq 0 on cs4236.
* Tue Feb  5 2002 tiwai@suse.de
- added pci_enable_device() in resume.
- removed commas from end of enum lists.
- fixed typo in header files.
* Mon Feb  4 2002 tiwai@suse.de
- added GPL license tags on some modules.
- fixed capture rate on ens1371.
- changes for the latest doxygen.
- fixed oss mixer misbehavior.
- added a new pnp id for cs4236.
- fixed emu10k1 wavetable function.
- fixed compile warning of emu10k1 mpu401 code.
- added missing MODULE_DEVICE_TABLES to some modules.
* Fri Feb  1 2002 tiwai@suse.de
- open OSS pcm devices on the non-blocking mode as default.
* Fri Feb  1 2002 tiwai@suse.de
- added initial support for SB Audigy.
- added initial support for TerraTec DMX 6Fire.
- fixed oops on ALS4000.
- fixed the installation path of modules.
- fixed oops in oss plugin module.
- improved/fixed digital output on cmipci driver.
- added pnp id for ALS200 to alsa100 driver.
- improved mpu401 input check.
- clean up of driver codes. addition of __devinit and
  __devinitdata.
- fixed typo in the description of module option in sb16.
- updated cards.txt and cardids.txt.
- renamed varibles for joystick init script.
- added comments about ac3dec in README.SuSE.
* Fri Jan 25 2002 tiwai@suse.de
- more fixes for cmipci driver.
- fix for nm256 (Dell Latitude LS).
- kmerge/Config.in fixes.
- removed ac3dec from alsa-tools tarball due to potential
  license problems.  disabled build of ac3dec.
- added a colon in start up of alsasound again.
  it's better :)
- more fixes for alsa-lib docs.
* Tue Jan 22 2002 tiwai@suse.de
- added a new pci id for ens1371.
- added support for NVidia Nforce (intel8x0).
- removed snd_enable_midi/fm options from cmipci driver.
- fixed 4ch playback mode on cmipci driver.
- more fixes of documents for alsa pcm plugins.
- fixed id of mixer on ESS Allego.
- fixed module names in README.SuSE.
* Thu Jan 17 2002 tiwai@suse.de
- better handling of enum strings in alsactl get/set.
* Thu Jan 17 2002 tiwai@suse.de
- removed gpm from StartRequires in alsasound init script.
- fixed maestro3 initialization bug.
- improved documentation of alsa-lib plugins.
- merged ARM patch into alsa-lib.
* Thu Jan 17 2002 uli@suse.de
- fixed to build on ARM
* Wed Jan 16 2002 egmont@suselinux.hu
- removed colons from startup/shutdown messages.
* Tue Jan 15 2002 schwab@suse.de
- Fix missing declarations in kernel drivers.
* Mon Jan 14 2002 tiwai@suse.de
- added get & set commands to alsactl.
- fixed joystick init script.
- more documents for doxygen.
* Fri Jan 11 2002 tiwai@suse.de
- fixed compile of alsa-kernel on ia64.
- fixed renaming via686a -> via686.
* Wed Jan  9 2002 tiwai@suse.de
- fixed infinite loop when playback drain is failed.
* Tue Jan  8 2002 tiwai@suse.de
- don't call depmod in alsa-driver when DESTDIR is set.
* Tue Jan  8 2002 tiwai@suse.de
- renamed from sysconfig/alsa to sysconfig/sound.
- fixed routing of ice1712 driver.
- added enable_loopback option to snd-ac97-codec module.
- updated gamix to ver.1.99.p11.
- added -c option to envy24control.
- fixed -c option for ac3dec.
- added the list of drivers compiled for each arch.
  Makefile.module reads the generated list file when exists.
  so far provided only for ia64.
* Tue Jan  8 2002 tiwai@suse.de
- removed sysconfig files from filelist.
* Mon Jan  7 2002 tiwai@suse.de
- fixed name of synth modules (for auto-loading).
- checked linux/pm.h in configure script.
* Mon Jan  7 2002 tiwai@suse.de
- added missing header files from alsa-kernel to devel package.
- fixed calculations of timeout in some drivers.
- many fixes for compile on 2.2 kernel.
- asoundef.h is incldued in alsa-lib (not symlinked).
- added sysconfig files as ghost to filelist.
- check old modules names in /etc/modules.conf and rename them
  automatically during post-install.
* Fri Jan  4 2002 tiwai@suse.de
- renaming of driver modules.
  all snd-card-xxx modules are renamed to snd-xxx.
  the old module configuration must be updated.  sorry.
  together with this change, cardids.txt is converted, too.
- split alsa driver sources.
  (a step for kernel 2.5 integration.)
  alsa-kernel tarball is provided individually.
- move LOAD_ALSA_SEQ variable to /etc/sysconfig/alsa.
- fixed alsasound script.
* Thu Dec 13 2001 tiwai@suse.de
- fix alsasound: don't try to load sequencer and version-check
  when no card drivers are loaded.
- better renaming from START_ALSA_SEQ to LOAD_ALSA_SEQ.
- added joystick init script. (only for testing yet)
  using /etc/sysconfig/joystick for configuration.
- remove (rename) the old /etc/asound.conf if found.
- removed kernel-source from neededforbuild.
* Thu Dec 13 2001 tiwai@suse.de
- fixed eapd hack on cs46xx (now km_alsa is fixed for build).
- more configurable pcm parameter for dummy driver.
- added snd_pcm_route_determine_ttable().
* Wed Dec 12 2001 iwai@suse.de
- added missing alsa-driver documents.
* Tue Dec 11 2001 tiwai@suse.de
- added joystick support on ymfpci driver:
  snd_joystick_port module option is added (default disabled).
  Needs ns558 module.
- added joystick support on es1938 (ess solo1) and sonicvibes
  drivers (on 2.4 kernel only).
  The driver handles gameport directly, so ns558 module is
  not necessary.
- added joystick support on es1968 (maestro2) driver.
  A new control switch "Joystick" is added.  Needs ns558.
- added joystick support on cs4281 driver.
  handles gameport directly.  No ns558 needed.
- fixed alsasound script to unload gameport module automatically.
- run update-deps on alsa-driver during build stage so that
  configure in km_alsa is properly generated.
- fixed compile of alsa-lib on ia64.
- changed snd_pcm_mmap_* handling.
* Mon Dec 10 2001 tiwai@suse.de
- fixed typo in tumbler driver.
- fixed mono conversion plugin in alsa-lib.
- fixed configure of alsa-driver on alpha.
- fixed window resizing of alsamixer.
* Fri Dec  7 2001 tiwai@suse.de
- PM support on opl3sa driver.
- HW volume support from docking station on es1968.
- Fixed GPL license tag on some modules.
- experimental support of LADSPA plugin layer.
* Fri Dec  7 2001 tiwai@suse.de
- fixed pmac (tumbler) driver.
- fixed trident latency problem.
- no longer inclusion of linux asm header files in alsa-lib.
- fixed module descriptions in cs4232 and es18xx modules.
- check ALSA driver version in alsasound init script.
- fixed compile of maestro3 driver on 2.2 kernel.
* Tue Dec  4 2001 tiwai@suse.de
- fixed typo in intel8x0 driver.
- build alsa-docs package on all architectures.
- merged kernel-header hack patch for non-intel architectures.
* Mon Dec  3 2001 tiwai@suse.de
- updated to ALSA 0.9.0 beta (CVS 2001.12.03)
- split alsa-docs package for ALSA documentation.
  (so far only on i386 due to problem of doxygen)
- as10k1 is not built to avoid conflict with emu-tools package.
* Tue Nov 27 2001 tiwai@suse.de
- fixed oops at removing cs461x driver with amp hack.
* Fri Nov 23 2001 tiwai@suse.de
- added the last missing patch into patch archive.. sorry.
* Fri Nov 23 2001 tiwai@suse.de
- fixed compile of maestro3 driver on 2.2 kernel.
* Thu Nov 22 2001 tiwai@suse.de
- use new macros for fill-up and init script
- fixes for building with normal user mode:
  rpm --rebuild should work with normal user.
* Wed Nov 21 2001 tiwai@suse.de
- fixed permission of proc device files on the latest kernel.
- fixed IrDA on Dell Inspiron 4000 notebook.
- replaced include malloc.h with slab.h (obsoleted).
- fixed expansion of variable length argument macros.
- use set_current_state() macro.
- fixed typo in ymfpci capture switch.
* Fri Nov  9 2001 tiwai@suse.de
- merged with the latest 0.5.12 tarball release.
- fixed installation of alsa.m4 file.
- fixed potential compile warnings.
- clean up spec file.
- build alsa-lib and alsa-utils inside specfile without extra
  Makefile.
- gettextize gamix
* Mon Nov  5 2001 tiwai@suse.de
- libtoolized alsa-lib & alsa-utils.
- fix compile of alsa-lib on non-gcc system.
  the mixer sort functions become thread-unsafe.
* Wed Oct 17 2001 tiwai@suse.de
- fixed compile of isapnp.o on 2.2 kernel.
* Mon Oct 15 2001 tiwai@suse.de
- fixed missing exported symbols in snd-synth-emux module.
- added GPL module license to each module.
  necessary for the latest 2.4 kernel and modutils.
* Fri Oct 12 2001 tiwai@suse.de
- added missing EXPORT_NO_SYMBOLS to the relevant modules.
* Thu Oct 11 2001 tiwai@suse.de
- fixed new feature calls for the latest benh kernel
  (only for ppc)
- improved cardname output of pmac driver.
* Tue Oct  9 2001 tiwai@suse.de
- added a new pnp id for cs4236.
- fixed again mute bitmask for screamer dev.10.
- added new pnp entries to card id database.
* Mon Oct  8 2001 tiwai@suse.de
- fixed auto-muting on screamer dev.10 (bug #11690).
- added a new pnp id for sbawe.
* Tue Oct  2 2001 tiwai@suse.de
- fixed oops / lock-up on es1968 driver (bug #11562).
- fixed oops / lock-up when ROM soundfont is loaded on emu10k1.
- added check for 586MMX in configure script.
* Mon Oct  1 2001 tiwai@suse.de
- added snd_enable option to awacs driver again (bug #11339).
- fixed auto-mute check on screamer dev.8 (ppc driver).
- added conditional rescheduling while loading samples on emu8000.
* Thu Sep 27 2001 tiwai@suse.de
- fixed line-out plug check for screamer with dev != 0.
  now auto-muting should work on most of pmacs.
- added snd_auto_mute_mask flag for user to set the bit-mask
  value.
* Thu Sep 20 2001 tiwai@suse.de
- changed OSS version number to 3.8.2, to avoid warning from
  gmix (Bug #10523)
* Thu Sep 20 2001 tiwai@suse.de
- added a new pnp id (SMM7180) for ad1816a.
- added toggle command to amixer.
* Wed Sep 19 2001 tiwai@suse.de
- added missing pnp id to card database.
* Fri Sep 14 2001 tiwai@suse.de
- removed cache for snd_cards_mask() in alsa-lib
  so that alsa-lib can detects the change of status (Bug #10314).
* Wed Sep 12 2001 tiwai@suse.de
- improved measurement of clock on es1968.
- increased maximum timer frequency on es1968.
  better responce expected for small fragments.
- improved measurement of ac97 clock on intel8x0.
* Mon Sep 10 2001 tiwai@suse.de
- fixed mpu initialization on ymf744/754.
- added snd_mpu_irq option for cmipci driver.  some cards need
  an extra interrupt for mpu401.  when the interrupt is shared
  with pcm, pass -1 (as default).
* Fri Sep  7 2001 tiwai@suse.de
- added auto measurement of clock on es1968 chips.
- added amplifier switch for DACA on pmac.  As default it's on.
* Thu Sep  6 2001 tiwai@suse.de
- fixed the clock value of es1978 chip.
- Makefile.module accept ALSA_MODULE_TO_BUILD to pass as
  a configure option.  Each kernel package can give --with-cards
  option to specify the drivers to be compiled.
  As default all drivers are built.
* Wed Sep  5 2001 tiwai@suse.de
- fixed playback on ymfpci with small fragment size.
- fixed clicking noises during playback on es1968.
* Tue Sep  4 2001 tiwai@suse.de
- fixed initialization/suspend/resume on pmac DACA and Tumbler
  chips.  patch is merged to cvs.
- changes "Wave Playback Volume" on alsatest (for ymfpci driver).
- updated README.SuSE, power management section.
* Thu Aug 30 2001 tiwai@suse.de
- pmac (awacs) driver detects the status of headphone and
  mutes/unmutes the speaker automatically.
- alsaconf changes "Speaker" and "Line Out" volumes at sound test
  (for awacs driver).
* Tue Aug 28 2001 tiwai@suse.de
- fixed pc-speaker driver for playback.
- fixed detection of keywest i2c device on ppc.
* Mon Aug 27 2001 tiwai@suse.de
- integrated i2c-keywest code into awacs driver.
  no longer i2c-core and i2c-keywest modules are required.
* Mon Aug 27 2001 tiwai@suse.de
- fixed deadlock during capture on maestro3 driver (SMP).
- added support for ESS Canyon3D-2/LE PCI (to maestro3 driver).
- merged additional patches to cvs.
- do not return the error code at stopping alsasound script
  (bug #9888).
- added isa pnp id for ALS200 to als100 driver.
* Fri Aug 24 2001 tiwai@suse.de
- added mixer control for DACA (iBook) on awacs driver.
  i2c support on kernel (i2c-core and i2c-keywest) is required
  as well.
* Thu Aug 23 2001 tiwai@suse.de
- added experimental support for ibook2 (tumbler) on awacs driver.
  i2c support on kernel is required.  for mixer control,
  i2c-keywest module should be formerly loaded.
  only master and beep playback volumes are available.
- reduced clocks at beginning of playback on ad1848.
* Wed Aug 22 2001 tiwai@suse.de
- fixed race condition in open/close of cmipci driver.
  protected by mutex.
- fixed the bug in rate conversion of alsa-lib (this happens
  only when different format rate is returned in setup like sb8).
- added pci_enable_device in emu10k1 driver.
- fixed deadlock of mozart driver.
- added snd_isapnp option to snd-card-opti9x driver.
* Wed Aug 15 2001 tiwai@suse.de
- fixed start up scripts for emu10k1/sbawe to support multiple
  cards.
- disabled isapnp on ppc prep (only for 2.2 kernel).
- fixed configure script to set CONFIG_SND_ISA correctly.
- added pc speaker driver (not compiled as default :)
* Tue Aug 14 2001 schwab@suse.de
- Fix alsa-driver configure script: don't force CONFIG_SND_ISA.
* Thu Aug  9 2001 tiwai@suse.de
- fixed card id database.
- fixed stereo playback on es1968.
- fixed pcm playback on emu10k1.
* Fri Aug  3 2001 tiwai@suse.de
- fixed alsasound compliant to LSB.
* Wed Aug  1 2001 tiwai@suse.de
- removed snd_max_channels module option from cmipci driver.
- support for large soundfonts (caching) on emu10k1 driver.
- fixed card database.
- fixed module descriptions.
* Fri Jul 13 2001 tiwai@suse.de
- use _prefix & co.
* Fri Jul 13 2001 grimmer@suse.de
- fixed man page file list (using wild cards instead including
  the directory itself)
* Tue Jul 10 2001 tiwai@suse.de
- improved mixer volumes for spdif controls on ymfpci driver.
* Thu Jul  5 2001 iwai@suse.de
- added new pnp id for terratec maestro32/96.
- fixed compile on ppc - isa cards are enabled.
- check undefined dma_addr_t & etc in configure script.
* Tue Jun 26 2001 tiwai@suse.de
- added snd_nonblock_open module option to pcm-oss module.
- fixed clkrun hack on cs461x driver.
* Thu Jun  7 2001 tiwai@suse.de
- added a new pnp id for sb16.
- improved intel8x0 driver.
  + auto-probing of ac97 clock.
  + pm support.
  + fragment size fix.
  + lowlevel module is removed.
- added snd_dsp_map and snd_adsp_map module options to pcm-oss
  module.
* Mon May 28 2001 tiwai@suse.de
- added a new pnp id for azt2320.
- fixed amp_enable hack for hercules game theatre xp.
- swapped spdif 5V switch on cmipci driver.
- initialize more two registers on ymfpci driver.
- fixed kernel-version numbering (in alsa-driver rpms).
* Tue May 15 2001 tiwai@suse.de
- include alsa-driver 0.5.11 tarball.  patches removed.
* Tue May 15 2001 tiwai@suse.de
- fixed/improved alsaconf:
  + added -l, -m options
  + use static card db
  + use /proc/isapnp instead of pnpdump
  + add /sbin path to modutils commands (to start from KDE menu)
* Fri May 11 2001 tiwai@suse.de
- fixed alsaconf.
* Fri May 11 2001 tiwai@suse.de
- Fixed pm code.
- Added ali5451 driver.
* Thu May 10 2001 tiwai@suse.de
- Fixed pm code on ymfpci, es1968, nm256 and cs461x.
- Workaround against hang up on es1968.
* Wed May  9 2001 tiwai@suse.de
- Added a workaround for buzzing on ymf754.
- alsaconf uses cardids.txt if exists.
* Tue May  8 2001 tiwai@suse.de
- Added auto-probing of legcay isa chips to alsaconf.
* Mon May  7 2001 tiwai@suse.de
- Improved alsaconf:
  + can choose a soundcard if multiple cards exit.
  + saner manipulation of /etc/modules.conf
- Added a new pnp id for ad1816.
- Acquire irq after chip detection on es1968 driver.
- fm/mpu_port don't have to be set on non-isapnp opl3sa2.
* Thu May  3 2001 tiwai@suse.de
- Added a new pnp id for sbawe.
- Fixed build on 2.2 smp kernel.
* Wed May  2 2001 tiwai@suse.de
- Fixed sequencer tempo bug.
- Fixed compile warnings regarding pointer cast.
- Check address bit mask of allocated region on es1968 and
  maestro3 drivers.
* Mon Apr 30 2001 tiwai@suse.de
- Fixed alsaconf (for the latest modinfo).
- Added gpm to RequireStart in init script (to avoid irq conflicts)
- Fixed private_value of kswitch from int to long. (This fixes the
  bug below correctly.)
* Sun Apr 29 2001 schwab@suse.de
- Fix invalid cast in cmipci driver.
* Fri Apr 27 2001 bk@suse.de
- fixed all_notes_off script(no \r's and no delay)
- fixed alsa driver start scripts emu10k1 and sbawe
  (fix for creative soundfont path used by yast2 and status improvement)
- fixed permissions of alsa driver start scripts (/etc/alsa.d files)
- filelist fix: add /etc/alsa.d (the dir itself) also to the alsa
  filelist (/etc/alsa.d is not mentionend in aaa_dir)
* Tue Apr 10 2001 tiwai@suse.de
- Fixed INSTALL document.
- Added new chips to cards.txt and cardids.txt.
- Fixed compile on the very recent kernel.
- Clean up of emu10k1/sbawe scripts.
* Tue Apr 10 2001 tiwai@suse.de
- Added all_notes_off script.
- Added -P/-C options to aplay for AC3 playback.
- Fixed typos in documents.
- Fixed version numbering of alsa-utils.
* Fri Apr  6 2001 tiwai@suse.de
- New test sound by mana@suse.de.
- Improved spdif/mixer support on cmipci driver.
- Fixed overflow / zero-divide error of timer tempo calculation.
* Mon Apr  2 2001 kukuk@suse.de
- Remove kernel_headers from requires
* Fri Mar 23 2001 tiwai@suse.de
- Fixed compile on 2.2 kernel again.
- Fixed memory leak.
- Added external amp and clkrun hacks for cs461x (untested).
  snd_clkrun module option is obsoleted.
- Disabled debug options.
- Fixed sequencer bugs.
* Wed Mar 21 2001 tiwai@suse.de
- Removed tricky SuSEconfig for alsa-devel header files.
  All header files will be installed simplly to /usr/include/linux
  and /usr/include/sys, since /usr/include/linux is now included
  in glibc-devel package.
* Wed Mar 21 2001 tiwai@suse.de
- Fixed compile of alsa-driver on 2.2 kernel.
* Tue Mar 20 2001 tiwai@suse.de
- Support for ia64.
- Fixed typo in azt2320 driver.
* Mon Mar 12 2001 tiwai@suse.de
- Added a pseudo master volume to awacs driver
  (to keep compatibility with other ones).
- Removed invalid elements from awacs / burgundy mixer.
* Fri Mar  9 2001 tiwai@suse.de
- Fixed bogus export of pm_xxx functions on 2.4 kernel.
  (fixed conflict with pcmcia_core.o)
* Tue Mar  6 2001 tiwai@suse.de
- Added a new pnp id for neomagic neowave (on acer notebook)
  to opl3sa2 driver.
- Fixed nm256 signature detection more strictly.
* Mon Mar  5 2001 tiwai@suse.de
- Fixed endian and rate checks for screamer of ppc awacs driver.
* Thu Mar  1 2001 tiwai@suse.de
- Synced with the latest 0.5.x source (awacs is now in main tree).
- Fixed spinlock in awacs driver.
* Mon Feb 26 2001 tiwai@suse.de
- Fixed Makefile.module for km_alsa.
- Added -b option to depmod in alsa-driver Makefile.
- Improved sbawe/emu10k1 scripts.
* Tue Feb 20 2001 tiwai@suse.de
- Added a new pnp id for sb16.
* Thu Feb 15 2001 tiwai@suse.de
- Minor fixes of awacs.
- Added mic-gain, aux input mixer controls for cmipci.
- Added support of card-dependent scripts (under /etc/alsa.d).
* Fri Feb  9 2001 tiwai@suse.de
- Added new pnp id for cs4236.
- Fixed OSS GET_DSP_RATE ioctl to get the nearest pcm rate.
- Fixed alsasound script.
- Changed byte-swap detection on awacs driver.
- Disabled capture on awacs driver with DACA chip.
- Saner nm256 signature check.
* Mon Feb  5 2001 tiwai@suse.de
- Added reboot notifier callback to ymfpci, es1968 and maestro3
  drivers.
- Fixed ac97 codec routine.
* Thu Feb  1 2001 tiwai@suse.de
- Fixed Makefile again.
- Updated to alsa-lib-0.5.10b.
* Wed Jan 31 2001 tiwai@suse.de
- Fixed initialization on some CS4236 chip.
* Wed Jan 31 2001 tiwai@suse.de
- Fixed Makefile of alsa-driver for DESTDIR support.
* Mon Jan 29 2001 tiwai@suse.de
- Added $remote_fs to RequestStart/Stop in alsasound init script.
* Mon Jan 29 2001 tiwai@suse.de
- Updated to alsa-driver-0.5.10b.
  (Addition of VIA VT8233 driver)
- Fixed typo wrt CS4281 pci id.
- Added check for pmac-awacs driver to alsaconf script.
* Tue Jan 23 2001 schwab@suse.de
- Reenable building of kernel module on ia64.
* Wed Jan 17 2001 tiwai@suse.de
- Added experimental support for ibook DACA (no mixer yet).
- Fixed DESTDIR in alsa-driver's Makefile.
* Tue Jan 16 2001 tiwai@suse.de
- Fixed initialization of maestro3 driver on 2.4 kernel.
- Fixed 8bit linear conversion in pcm_misc.c.
* Thu Jan 11 2001 tiwai@suse.de
- Fixed typos in documents.
- Added missing alsamixer & gamix documents.
* Thu Jan 11 2001 tiwai@suse.de
- More fix on ac97codec.
- Fixed alsasound script to avoid hang at shutdown.
* Wed Jan 10 2001 tiwai@suse.de
- Fixed missing exports of pci_compat stuffs.
* Wed Jan 10 2001 tiwai@suse.de
- Fixed clkrun init in resume of cs461x.
- Fixed initialization of ac97 on CS4297A rev B.
- Fixed alsaconf script (Bug #5393).
- Fixed snd_dma_size function.
- Fixed documentation, README.SuSE, README.alsadev.
* Mon Jan  8 2001 tiwai@suse.de
- Fixed warning on comiple.
- Added a note for irq problem on via686a-SMP mobo to
  alsa-driver/INSTALL.
- Changed compile condition: CONFIG_APM -> CONFIG_PM
* Mon Jan  8 2001 tiwai@suse.de
- Updated to alsa-driver-0.5.10a.
  (including better condition check for wavefront.c)
- Fixed compile on 2.2 kernel.
- Fixed handling of non-interleave data in the mmap plugin.
* Fri Jan  5 2001 tiwai@suse.de
- Improve/bugfix of es1968 (maestro/2e) driver.
  + Dead spinlock is fixed.
  + Stereo capture is available now.
  + APM support.
- Added a new pnp id for cs4236.
- Fixed compile on 2.4.0 kernel.  Can no longer compile on old
  2.4.0-testXX kernels.
* Thu Jan  4 2001 tiwai@suse.de
- Added new revision id for ens1371.
* Wed Jan  3 2001 tiwai@suse.de
- Fixed typo in amixer (wrong memory allocation).
- Fixed silent notes on sequencer.
- Added snd_vaio_hack option to nm256 driver.
- Fixed FM801 capture bug.
- Added new pnp id for cs4232.
- Fixed power management on maestro3.
- Fixed typo in cmi8330 driver.
* Tue Jan  2 2001 olh@suse.de
- add DESTDIR to Makefile.module and Makefile
* Sun Dec 31 2000 kukuk@suse.de
- Remove postinstall on SPARC and IA64
* Mon Dec 18 2000 tiwai@suse.de
- Fixed initialization of ymfpci driver.
* Mon Dec 18 2000 tiwai@suse.de
- Improved maestro3 driver: multiple streams & duplex support.
- Fixed pm support on cs4231,cs4232,cs4236.
- Fixed pm support on cs461x.
- Fixed alsaconf script to display the correct device name.
- Fixed cards.txt and cardids.txt entries.
* Fri Dec 15 2000 tiwai@suse.de
- Added Copyright tag to alsa-devel.
* Thu Dec 14 2000 tiwai@suse.de
- Fixed pm support on nm256.
- Fixed memory barrier problems on some alpha chips.
- Fixed alsasound script to kill OSS apps.
* Tue Dec 12 2000 tiwai@suse.de
- Added pm support for cs461x.
- Fixed typo on maestro3 - m3 chips should work now.
- Added pm support for maestro3.
- Added pm support for nm256.
- Fixed a wrong pnp id of azt2320.
* Mon Dec 11 2000 tiwai@suse.de
- Fixed compile on suse 2.2.17 kernel.
* Fri Dec  8 2000 tiwai@suse.de
- Added NeoMagic NM256AV/ZX driver.
* Thu Dec  7 2000 tiwai@suse.de
- Updated to 0.5.10.
* Mon Dec  4 2000 tiwai@suse.de
- Added experimental Maestro3/Allegro driver.
- Added experimental CS4281 driver.
- Added START_ALSA and START_ALSA_SEQ in /etc/rc.config
  to ask start up of alsa services.
* Mon Dec  4 2000 ro@suse.de
- fix km_alsa build
* Mon Nov 27 2000 tiwai@suse.de
- alsa-driver package is no longer compiled.  cards.txt and
  cardids.txt are provided as extra sources.
- Added new id for cs4236.
- Moved /sbin/init.d -> /etc/init.d
    /sbin/rcalsasound -> /usr/sbin/rcalsasound
* Fri Nov 24 2000 tiwai@suse.de
- Added hack to avoid hang on opl3sa2 driver.
- Fixed AWACS driver.
- Enabled basic debug option.
* Mon Nov 20 2000 tiwai@suse.de
- Use insserv in post-install for creating init.d scripts.
- Fixed oops in sequencer.
- Added new id for cs4236.
- Fixed oops in ac97 (some of cs461x chips have caused).
- Updated PMac AWACS driver.
* Thu Nov 16 2000 tiwai@suse.de
- Added PMac AWACS driver (experimentally).
- New pnp id for cs4236.
- Fixed initialization of es1968 on 2.4 kernel.
- Fixed rate and voices plugins for big-endian.
- Fixed usage and man page of alsamixer and aplay.
* Fri Nov 10 2000 kukuk@suse.de
- Change requires from libc to glibc-devel
* Thu Nov  9 2000 tiwai@suse.de
- Updated gamix to 1.11.
- Load sequencer modules automagically in alsasound script.
* Mon Nov  6 2000 tiwai@suse.de
- Move libasound.so into alsa-devel package.
- Fixed autobuild on beta-i386.
- New pnp id for sb16.
* Thu Nov  2 2000 tiwai@suse.de
- Change for long-name packages (alsa-devel and alsa-driver).
- No longer generate sndcards.ycp (contained in y2t_snd package).
* Tue Oct 31 2000 tiwai@suse.de
- Added ALS4000 driver.
- Fixed typo of ac97 codec.
- Changed loops_per_sec to loops_per_jiffy in wavefront.c.
- Added snd_ac97_clock module parameter for i815 chip.
* Tue Oct 17 2000 tiwai@suse.de
- Fixed a bug in sb8 MIDI input.
- Fixed bugs in standard mpu401-uart.
* Wed Oct 11 2000 tiwai@suse.de
- Added a new pnp id for SB16.
- Added a new id for AC97.
* Tue Oct 10 2000 tiwai@suse.de
- Updated to alsa-driver-0.5.9d.
- Fixed a minor bug of sequencer midi emulation.
- Fixed MIDI UART on CMIPCI driver.
* Fri Oct  6 2000 tiwai@suse.de
- Added new id for CS4236.
- Fixed NOTE events handling in sequencer.
- Updated to gamix-1.09p17.
* Wed Sep 27 2000 tiwai@suse.de
- Use /lib/modules/%%{kernel_version}/misc directory for generating
  sndcards.ycp
* Mon Sep 25 2000 tiwai@suse.de
- Fixed generating sndcards.ycp.
- New pnp id for cs4236.
- New pci id for CM8738B.
- More SPDIF support on CMI PCI driver.
- Fixed loopback bug in alsa-lib.
* Thu Sep 14 2000 tiwai@suse.de
- Fixed deadlock of OSS sequencer emulation.
- Fixed S/PDIF input on YMFPCI driver.
- Support new switches for CMIPCI driver.
- Support for 2.2.18 kernel.
- Send MIDI reset after closing sequencer MIDI devices.
- Minor update of README.SuSE.
* Mon Sep  4 2000 tiwai@suse.de
- Updated to alsa-driver-0.5.9c / utils-0.5.9b.
- Fixed emu10k1 filter cutoff pops and clicks.
- Put all patches into patches.tar.bz2.
- Put (currently unused) files for custom subpackages into
  custom.*.tar.bz2.
- Include gendb script from y2t_sndd to allow users rebuild the
  source RPM without the SuSE internal package.
- More fixes of README.SuSE.
* Fri Sep  1 2000 tiwai@suse.de
- Added support of i815.
- Fixed ymfpci typos.
- Fixed sequencer instrument layer.
- Fixed emu8000 filter cutoff pops and clicks.
- New option -x for aconnect.
- Bug fixes of memory leak by aseqnet.
* Mon Aug 28 2000 tiwai@suse.de
- Add new ids for ad1816a, aztec and sb32.
- Fix internal synth of emu8000 and emu10k1.
- Aplay bugfix.
- CMI PCI bugfix.
* Mon Aug 21 2000 tiwai@suse.de
- Update to alsa-utils 0.5.9a.
* Mon Aug 14 2000 tiwai@suse.de
- 64bit support on emu10k1.
- Bugfix of ENS1371 initialization.
- More bugfix of 64bit support.
* Mon Aug 14 2000 tiwai@suse.de
- Update to 0.5.9a
- Minor bugfix of alsactl
* Wed Aug  9 2000 tiwai@suse.de
- More fixes for 64bit support.
* Wed Aug  9 2000 kukuk@suse.de
- On SPARC, only include the alsa libraries
* Mon Aug  7 2000 tiwai@suse.de
- Update to 0.5.9.
- Fix warning messages due to 64bit support.
* Fri Aug  4 2000 tiwai@suse.de
- Ignore MPU initialization on CS4236 if not reported by isapnp
  (for Dell 410 Workstation).
- Fix annoying kmix messages for emu10k1 mixer.
- Improve YMFPCI fragment size calculation.
* Tue Aug  1 2000 tiwai@suse.de
- Fix Oops in rawmidi when accessed through ALSA sequencer.
* Fri Jul 28 2000 tiwai@suse.de
- Take KDE_Startup.wave from kbase package as test.wav to reduce
  autobuild time.  kbase is removed from the neededtobuild list.
* Thu Jul 27 2000 tiwai@suse.de
- Fix NULL pointer access in Opti93x driver.
- Add CLKRUN support for CS461x.  T20 and TP570E will work w/o
  disabling PCI Bus power management in BIOS.
- Use modprobe -c instead of reading config file in alsasound
  script.
* Fri Jul 21 2000 tiwai@suse.de
- Fix wrong directory name with $RPM_BUILD_ROOT in libasound.la
  (in alsadev package only).
- Remove strict asound.h check at configuring alsa-lib.
- Call autoheader explicitly before compiling alsa-lib and
  alsa-utils.
* Wed Jul 19 2000 tiwai@suse.de
- Allow non-blocking mode to OSS rawmidi access.
- Fix a bug in caputer pointer calculation of via686a driver.
- Fix typos in README.SuSE.
- Install forgotten mo files of gamix.
* Fri Jul 14 2000 tiwai@suse.de
- Fix cards.txt.
- Add a missing codec ID for AC97.
- Add small i/o delays in ENS1370 driver.
* Thu Jul 13 2000 tiwai@suse.de
- Fixed triggerrun script.
- Fixed a bug in virmidi causing double kfree().
- Add README to alsadev package.
* Mon Jul 10 2000 tiwai@suse.de
- Swap left and right playback voices on YMF PCI.
- Fix alsaconf to display correct ISA-PnP card.
- Fix mixer input MUX of AD1816a driver.
- added %%{_docdir}/cardids.txt with full dirver info for hwinfo(bk).
- Alsasound script terminates processes using sound devices when
  stopped.
- Added status command to alsasound script.
* Fri Jul  7 2000 tiwai@suse.de
- Fix a wrong PnP FM-port initialization in sb16.
- Fix playback/capture clicks on SB-1.0.
- Fix Opti92x chip detection bug.
- Fix loud noises at start up of Opti92x-cs4231 driver.
* Thu Jul  6 2000 tiwai@suse.de
- Fix emu10k1 PCM playback bug.
- Fix YMFPCI plaback/record bug.
- Avoid freezing of YMFPCI driver when USB is uninitialized.
- Fix MPU401 SMP lock.
- Replace applause.wav with KDE_Startup.wav as test wave data
  for alsaconf and YaST2.
- Disable debug flag in km_alsa Makefile.
- Add -fno-builtin option for compile on PPC.
- Fix typos in INSTALL document.
- Fix unexported module parameters.
* Tue Jul  4 2000 kukuk@suse.de
- Don't include sndcards.ycp on ia64 and SPARC
* Mon Jul  3 2000 tiwai@suse.de
- Add /usr/lib/YaST2/sndcards.ycp to both alsa and alsadrv packages.
- Change from whistle.au to applause.wav for test sound (installed
  as /usr/share/sounds/alsa/test.wav).
* Wed Jun 28 2000 tiwai@suse.de
- Bugfix of devfs support.
- Bugfixes of emu10k1, cs461x and es1968 drivers.
- Include both libasound.so.1 and 1.0.1 in alsa package.
* Tue Jun 27 2000 tiwai@suse.de
- Update to ALSA driver 0.5.8b
- Update to gamix-1.09p15
- Fix a typo in README.SuSE
* Mon Jun 26 2000 kukuk@suse.de
- Don't build kernel modules on SPARC
* Fri Jun 23 2000 schwab@suse.de
- Fix use of %%suse_update_config.
- Don't build kernel modules on ia64.
* Fri Jun 16 2000 tiwai@suse.de
- Add pciutils as Requirements.
- Update of gamix to 1.0-p13.
- Bugfixes of ES1938 driver.
- Backport of ES1968 driver from 0.6.0 (with bugfixes).
- Add new pnp id to cs4236.
- Trident joystick support.
* Fri Jun 16 2000 cihlar@suse.cz
- linux/* header files installed under /usr/include/alsa/linux
- added SuSEconfig.alsa
- added triggers
* Fri Jun  9 2000 bk@suse.de
- fixed kernel_version define -> %%(uname -r)
- changed linux_header_dir to /usr/src/linux/include/linux
  (should fit with the pre-install then)
* Thu Jun  8 2000 ro@suse.de
- added pre-install for alsadev: create linux-srcdir if nonexistant
* Thu Jun  8 2000 tiwai@suse.de
- linux/* header files are installed under
  /usr/src/linux-VERSION.SuSE instead of /usr/src/linux
  (for avoiding confliction with lx_suse).
- Fix: minor bugs in ad1816
- Fix: sequencer patch loader
- Experimental APM support on YMF PCI driver
* Tue Jun  6 2000 tiwai@suse.de
- Official release of alsa-driver-0.5.8a, lib & utils-0.5.8 are
  included.
- alsadev installs header files under /usr/src/linux/include/linux
  instead of /usr/include/linux, owing to confliction with libc.
  libc and alsa packages are declared as requirements explicitly.
* Fri Jun  2 2000 tiwai@suse.de
- ALSA development package (alsadev) is split.
  It contains header files and static libraries.
- Updated to 06/02 snapshot of 0.5.8-pre version.
  YMF PCI driver is newly added.
* Fri May 26 2000 tiwai@suse.de
- updated to 0.5.8 pre-release version including bug fixes,
  addition of new driver (CMI 8x38 PCI) and device (direct FM
  OPL3 hwdep).
- bugfix of gamix
* Tue May  2 2000 bk@suse.de
- merged latest ppc and alpha fixes to one package
- fixed missing documentation
- added subpackage alsai8x0, customer package for intel8x0 chipset
* Fri Apr 28 2000 olh@suse.de
- add loops_per_sec.dif for ppc, guessing...
* Fri Apr 28 2000 olh@suse.de
- fix Makefile for 6.4-ppc
* Thu Apr 27 2000 bk@suse.de
- added fix for card out of range message from tiwai.
* Thu Apr 27 2000 bk@suse.de
- added subpackage alsadrv, includes update modules for k_deflt
- added subpackage alsavia6, special package for via chipset
- general cleanup
- converted buildroot
* Thu Apr  6 2000 bk@suse.de
- Updated to alsa-0.5.7,
- -%%{version} added to alsa-driver tree in km_alsa
- Updated README.SuSE
- Package build documentation updates.
- added config.{sub,guess} update call from schwab
* Fri Mar 31 2000 ro@suse.de
- libasound has version 1.0.0 now
* Fri Mar 17 2000 bk@suse.de
- updated to alsa-0.5.6, cvsexport 2000-03-17.tar.bz2
* Tue Mar 14 2000 bk@suse.de
- disabled kernel headers in the file list
* Sun Mar 12 2000 bk@suse.de
- added isapnp to Requires:
* Thu Mar  9 2000 ro@suse.de
- removed k_deflt from neededforbuild  (endless rebuild-loop)
* Thu Mar  9 2000 bk@suse.de
- fixed new selfwritten 0.5.5 alsaconf to actually work, new version: 0.5.5a
* Tue Mar  7 2000 bk@suse.de
- added gamix from http://www1.tcnet.ne.jp/fmurata/linux/down/
- alsa modules are no longer built here.
- wrote listcards.sh and added generated /usr/doc/packages/alsa/cards.txt
* Mon Mar  6 2000 ro@suse.de
- added Makefile.module and subpackage km_alsa to build the
  kernel-modules
* Sat Mar  4 2000 bk@suse.de
- updated to cvsexport 2000-03-03.tar.bz2
- removed not longer needed alsa-driver-configure.in.dif
- wrote quick hack alsaconf update from 0.4 to 0.5
* Thu Mar  2 2000 bk@suse.de
- updated to alsa-0.5.5, cvsexport 2000-03-02.tar.bz2
* Thu Feb 24 2000 bk@suse.de
- fixed alsa-driver configure to check autoconfig.h instead of cpuinfo
* Thu Feb 24 2000 bk@suse.de
- fixed up /usr/src/kernel-modules/alsa-driver source dir.
* Thu Feb 24 2000 bk@suse.de
- added alsa-driver source tree in /usr/src/kernel-modules/alsa-driver
* Fri Feb 18 2000 bk@suse.de
- ALSA 0.5 is back! Version 0.5.3 (cvsexport 2000-02-19)
- alsa config will be done through the yast2 module, or thorugh
  a termplat in the default modules.conf, which will be simple
  because 0.5 has PnP and PCI support.
- removed hack which got alsa compiled even if lx_suse disabled
  soundcore.o
- Added missing Dependency to dialog(Bug #1998)
* Mon Feb 14 2000 bk@suse.de
- went back to alsa-0.4.1i, last 0.5.2 version moved to BETA for
  later re-use when the new alsaconf for 0.5.2 is stable.
* Tue Feb  8 2000 bk@suse.de
- updated to improved, sent-back Makefile version from Jaroslav
- fixed and improved the Makefile further (now builds on AXP too)
- ensure that /usr/src/linux/.config is suitable for building ALSA
  (didn't exist on AXP)
* Mon Feb  7 2000 uli@suse.de
- fixed (again) for PPC
* Sun Feb  6 2000 bk@suse.de
- updated to alsa-0.5.2, cvsexport 2000-02-05
- based on pthomas's initial alsa5 work.
- alsaconf for alsa5 included and works if only the alsa modules
  which this package actively lists in the filelist are installed.
* Fri Jan 14 2000 bk@suse.de
- rpm version number fix (0.4.1d -> 0.4.1i)
* Thu Jan 13 2000 uli@suse.de
- fixed wavefront.c for PPC
* Wed Jan  5 2000 pthomas@suse.de
- fixed spec file to include the OSS emulation modules in file list
* Tue Jan  4 2000 bk@suse.de
- another fix related to the previous alsaconf fixes.
* Tue Jan  4 2000 bk@suse.de
- updated alsa-driver to alsa-driver-0.4.1i
- updated alsa-lib to alsa-lib-0.4.1e
- fixed some problems in alsaconf (Audiodrive18xx,ES1370 and others)
- improved alsaconf and alsasound scripts for /etc/asound.conf handling.
* Thu Nov 11 1999 bk@suse.de
- added changes from Phillip, oss-Modules vanished, I hope, this is correct.
* Sun Nov  7 1999 bk@suse.de
- fixed garbled sceen messages in alsaconf, now pretty window.
- run alsaconf stop on if alsa is loaded at startup of alsaconf.
* Sat Nov  6 1999 bk@suse.de
- added rcalsasound stop to alsaconf and say in the intro: close all sndapps
* Fri Nov  5 1999 bk@suse.de
- fixed ESS AudioDrive ES16x8 detecton and generating of
  /etc/conf.modules for this card. It works now, great!
* Fri Nov  5 1999 bk@suse.de
- fixes and updates to alsasound.diff from Phillip
- updated alsaconf to alsaconf-0.4.2(only change: fix for AWE64)
* Fri Nov  5 1999 bk@suse.de
- added changes from Klaus: Initilaze 2nd PCM on ESS 1969 chipset
  and fix y/z-typo.
- set PCM volume initial to 100%%(Master output is still 50%%) so people
  without a big amplifier will hear something and added a note for
  people with big amplifiers to lower volumer or say no at the play
  test sample question.
* Fri Nov  5 1999 ro@suse.de
- removed devices, now in "devs" package
* Tue Nov  2 1999 bk@suse.de
- fixed a bug alsaconf to configure the ESS Solo 1 Type Sound cards.
  (thanks to Thorsten Kukuk for testing and lending me his Travelmate
  to fix it)
  BTW: The ESS Solo 1 is detected and configured automatically now.
* Tue Nov  2 1999 bk@suse.de
- this one should make alsa really nice to use:
- run /sbin/init.d/alsasound stop&start from alsaconf
- initialize mixers to open channels
- added a sound sample to the package and play it in alsaconf
- added some help for the user to the end of alsaconf
* Mon Nov  1 1999 bk@suse.de
- fixed a small bug in alsaconf and added a supporting ending message
* Fri Oct 29 1999 bk@suse.de
- added /usr/sbin/alsaconf to the filelist
* Mon Oct 25 1999 bk@suse.de
- added alsaconf, a tool for configuring the alsa driver! Try it!
- added updates for README.SuSE and /sbin/init.d/alsasound from Philipp Thomas
* Sun Oct 24 1999 bk@suse.de
- updated alsa-driver to 0.4.1d
  minor bugfixes (CMI8330, 2+ soundcards, modules.conf handling,
  documentation files).
  Upgrade is recommended if your system has 2 or more soundcards.
- updated alsa-lib    to 0.4.1d (PCM cleanup fixes)
* Wed Oct 20 1999 bk@suse.de
- %%files: use a static list of sound drivers instead of wildcards.
* Mon Oct 11 1999 bk@suse.de
- updated alsa-driver to 0.4.1c
* Mon Oct 11 1999 ro@suse.de
- patched to compile wavefront.c on axp
- simplified specfile
* Tue Sep 21 1999 ro@suse.de
- fixed filelist
* Sat Sep 18 1999 bk@suse.de
- major update to version 0.4.1b, many changes
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Sun Aug 29 1999 ro@suse.de
- set kernel-version to 2.2.12
* Tue Jul 20 1999 bk@suse.de
- added libtoolize --force to use ltconfig and ltmain from libtool
* Sat Jul 17 1999 ro@suse.de
- set kernel version to 2.2.10
* Fri Jul 16 1999 ro@suse.de
- fixed filelist
* Thu Jul 15 1999 bk@suse.de
- minor doku update, Check added, postinstall exits with value 0.
* Mon Jun 28 1999 uli@suse.de
- added missing header files
* Fri Jun  4 1999 ro@suse.de
- changed kernel-ver to 2.2.9
* Sat May 22 1999 bk@suse.de
- fixed compile problem on alpha
- Documentation cleanup
- postinstall fixes
* Sat May  1 1999 ro@suse.de
- made the kernel-version a macro
* Mon Apr  5 1999 bs@suse.de
- fixed date strings in .changes.
* Thu Apr  1 1999 ro@suse.de
- changed "-"in Version to "_"
- activated patch to get README.SuSE
- cut down post-script
* Thu Apr  1 1999 bk@suse.de
- new package - Advanced Linux Sound Architecture (ALSA)
  version : CVS snapshot 1993-03-28
  homepage: http://alsa.jcu.cz
  patches : none, except README.SuSE and a fix to the alsasound script.
